/* GDocumentTest.c generated by valac 0.44.3, the Vala compiler
 * generated from GDocumentTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2011-2013  Richard Schwarting <aquarichy@gmail.com>
 * Copyright (C) 2011-2015  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Richard Schwarting <aquarichy@gmail.com>
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GDOCUMENT_TEST (gdocument_test_get_type ())
#define GDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GDOCUMENT_TEST, GDocumentTest))
#define GDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GDOCUMENT_TEST, GDocumentTestClass))
#define IS_GDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GDOCUMENT_TEST))
#define IS_GDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GDOCUMENT_TEST))
#define GDOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GDOCUMENT_TEST, GDocumentTestClass))

typedef struct _GDocumentTest GDocumentTest;
typedef struct _GDocumentTestClass GDocumentTestClass;
typedef struct _GDocumentTestPrivate GDocumentTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GDocumentTest {
	GXmlTest parent_instance;
	GDocumentTestPrivate * priv;
};

struct _GDocumentTestClass {
	GXmlTestClass parent_class;
};

static gpointer gdocument_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gdocument_test_get_type (void) G_GNUC_CONST;
void gdocument_test_add_tests (void);
static void __lambda5_ (void);
static void ___lambda5__gtest_func (void);
static void __lambda6_ (void);
static void ___lambda6__gtest_func (void);
static void __lambda7_ (void);
static void ___lambda7__gtest_func (void);
static void __lambda8_ (void);
static void ___lambda8__gtest_func (void);
static void __lambda9_ (void);
static void ___lambda9__gtest_func (void);
static void __lambda10_ (void);
static void ___lambda10__gtest_func (void);
static void __lambda11_ (void);
static void ___lambda11__gtest_func (void);
static void __lambda12_ (void);
static void ___lambda12__gtest_func (void);
static void __lambda13_ (void);
static void ___lambda13__gtest_func (void);
static void __lambda14_ (void);
static void ___lambda14__gtest_func (void);
static void __lambda15_ (void);
static void ___lambda15__gtest_func (void);
static void __lambda16_ (void);
static void ___lambda16__gtest_func (void);
static void __lambda17_ (void);
static void ___lambda17__gtest_func (void);
static void __lambda18_ (void);
static void ___lambda18__gtest_func (void);
static void __lambda19_ (void);
static void ___lambda19__gtest_func (void);
static void __lambda20_ (void);
static void ___lambda20__gtest_func (void);
static void __lambda21_ (void);
static void ___lambda21__gtest_func (void);
static void __lambda22_ (void);
static void ___lambda22__gtest_func (void);
static void __lambda23_ (void);
static void ___lambda23__gtest_func (void);
static void __lambda24_ (void);
static void ___lambda24__gtest_func (void);
static void __lambda25_ (void);
static void ___lambda25__gtest_func (void);
static void __lambda26_ (void);
static void ___lambda26__gtest_func (void);
static void __lambda27_ (void);
static void ___lambda27__gtest_func (void);
GDocumentTest* gdocument_test_new (void);
GDocumentTest* gdocument_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static void
__lambda5_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		GXmlNode* root = NULL;
		GXmlNode* _tmp1_;
		GeeBidirList* _tmp2_;
		GeeBidirList* _tmp3_;
		GeeBidirList* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlNode* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
#line 31 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 31 "GDocumentTest.vala"
		d = _tmp0_;
#line 32 "GDocumentTest.vala"
		_tmp1_ = gxml_document_create_element ((GXmlDocument*) d, "root", &_inner_error0_);
#line 32 "GDocumentTest.vala"
		root = _tmp1_;
#line 32 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 32 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 215 "GDocumentTest.c"
			goto __catch19_g_error;
		}
#line 33 "GDocumentTest.vala"
		_tmp2_ = gxml_gnode_get_children_nodes ((GXmlGNode*) d);
#line 33 "GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 33 "GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 33 "GDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp4_, root);
#line 33 "GDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 34 "GDocumentTest.vala"
		_tmp5_ = gxml_document_get_root ((GXmlDocument*) d);
#line 34 "GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 34 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 34 "GDocumentTest.vala"
		_vala_assert (_tmp7_ != NULL, "d.root != null");
#line 34 "GDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 35 "GDocumentTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) d);
#line 35 "GDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 35 "GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 35 "GDocumentTest.vala"
		_tmp11_ = gxml_node_get_name (_tmp10_);
#line 35 "GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 35 "GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 35 "GDocumentTest.vala"
		_tmp14_ = g_strconcat ("Root name: ", _tmp13_, NULL);
#line 35 "GDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 35 "GDocumentTest.vala"
		g_test_message ("%s", _tmp15_);
#line 35 "GDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 35 "GDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 35 "GDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 36 "GDocumentTest.vala"
		_tmp16_ = gxml_document_get_root ((GXmlDocument*) d);
#line 36 "GDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 36 "GDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 36 "GDocumentTest.vala"
		_tmp19_ = gxml_node_get_name (_tmp18_);
#line 36 "GDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 36 "GDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 36 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "root") == 0, "d.root.name == \"root\"");
#line 36 "GDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 36 "GDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 37 "GDocumentTest.vala"
		_tmp22_ = gxml_document_get_root ((GXmlDocument*) d);
#line 37 "GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 37 "GDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 37 "GDocumentTest.vala"
		_tmp25_ = gxml_node_to_string (_tmp24_);
#line 37 "GDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 37 "GDocumentTest.vala"
		_tmp27_ = g_strconcat ("Root string: ", _tmp26_, NULL);
#line 37 "GDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 37 "GDocumentTest.vala"
		g_test_message ("%s", _tmp28_);
#line 37 "GDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 37 "GDocumentTest.vala"
		_g_free0 (_tmp26_);
#line 37 "GDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 38 "GDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) d);
#line 38 "GDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 38 "GDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 38 "GDocumentTest.vala"
		_tmp32_ = gxml_node_to_string (_tmp31_);
#line 38 "GDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 38 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp33_, "<root/>") == 0, "d.root.to_string () == \"<root/>\"");
#line 38 "GDocumentTest.vala"
		_g_free0 (_tmp33_);
#line 38 "GDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 30 "GDocumentTest.vala"
		_g_object_unref0 (root);
#line 30 "GDocumentTest.vala"
		_g_object_unref0 (d);
#line 322 "GDocumentTest.c"
	}
	goto __finally19;
	__catch19_g_error:
	{
#line 30 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 30 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 39 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 333 "GDocumentTest.c"
	}
	__finally19:
#line 30 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 30 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 30 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 30 "GDocumentTest.vala"
		return;
#line 344 "GDocumentTest.c"
	}
}

static void
___lambda5__gtest_func (void)
{
#line 29 "GDocumentTest.vala"
	__lambda5_ ();
#line 353 "GDocumentTest.c"
}

static void
__lambda6_ (void)
{
	GXmlGDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlGDocument* _tmp2_;
#line 44 "GDocumentTest.vala"
		g_test_message ("invalid file...");
#line 46 "GDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_path ("/tmp/asdfjlkansdlfjl", 0, &_inner_error0_);
#line 46 "GDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 46 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 373 "GDocumentTest.c"
			goto __catch20_g_error;
		}
#line 46 "GDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 46 "GDocumentTest.vala"
		_tmp0_ = NULL;
#line 46 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 46 "GDocumentTest.vala"
		doc = _tmp2_;
#line 47 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 43 "GDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 388 "GDocumentTest.c"
	}
	goto __finally20;
	__catch20_g_error:
	{
#line 43 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 43 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 397 "GDocumentTest.c"
	}
	__finally20:
#line 43 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 43 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 43 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 43 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 43 "GDocumentTest.vala"
		return;
#line 410 "GDocumentTest.c"
	}
	{
		GXmlGDocument* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_;
		GXmlGDocument* _tmp5_;
#line 52 "GDocumentTest.vala"
		_tmp4_ = gxml_gdocument_new_from_path ("/tmp/", 0, &_inner_error0_);
#line 52 "GDocumentTest.vala"
		_tmp3_ = _tmp4_;
#line 52 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 422 "GDocumentTest.c"
			goto __catch21_g_error;
		}
#line 52 "GDocumentTest.vala"
		_tmp5_ = _tmp3_;
#line 52 "GDocumentTest.vala"
		_tmp3_ = NULL;
#line 52 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 52 "GDocumentTest.vala"
		doc = _tmp5_;
#line 53 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 50 "GDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 437 "GDocumentTest.c"
	}
	goto __finally21;
	__catch21_g_error:
	{
#line 50 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 50 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 446 "GDocumentTest.c"
	}
	__finally21:
#line 50 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 50 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 50 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 50 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 50 "GDocumentTest.vala"
		return;
#line 459 "GDocumentTest.c"
	}
	{
		GXmlGDocument* _tmp6_ = NULL;
		GXmlGDocument* _tmp7_;
		GXmlGDocument* _tmp8_;
#line 56 "GDocumentTest.vala"
		_tmp7_ = gxml_gdocument_new_from_path ("test_invalid.xml", 0, &_inner_error0_);
#line 56 "GDocumentTest.vala"
		_tmp6_ = _tmp7_;
#line 56 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 471 "GDocumentTest.c"
			goto __catch22_g_error;
		}
#line 56 "GDocumentTest.vala"
		_tmp8_ = _tmp6_;
#line 56 "GDocumentTest.vala"
		_tmp6_ = NULL;
#line 56 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 56 "GDocumentTest.vala"
		doc = _tmp8_;
#line 57 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 55 "GDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 486 "GDocumentTest.c"
	}
	goto __finally22;
	__catch22_g_error:
	{
#line 55 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 55 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 495 "GDocumentTest.c"
	}
	__finally22:
#line 55 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 55 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 55 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 55 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 55 "GDocumentTest.vala"
		return;
#line 508 "GDocumentTest.c"
	}
#line 41 "GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 512 "GDocumentTest.c"
}

static void
___lambda6__gtest_func (void)
{
#line 41 "GDocumentTest.vala"
	__lambda6_ ();
#line 520 "GDocumentTest.c"
}

static void
__lambda7_ (void)
{
	GFile* fin = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 61 "GDocumentTest.vala"
	_tmp0_ = g_file_new_for_path (TEST_DIR "/test.xml");
#line 61 "GDocumentTest.vala"
	fin = _tmp0_;
#line 62 "GDocumentTest.vala"
	_tmp1_ = fin;
#line 62 "GDocumentTest.vala"
	_vala_assert (g_file_query_exists (_tmp1_, NULL), "fin.query_exists ()");
#line 538 "GDocumentTest.c"
	{
		GFileInputStream* instream = NULL;
		GFile* _tmp2_;
		GFileInputStream* _tmp3_;
		GXmlGDocument* doc = NULL;
		GFileInputStream* _tmp4_;
		GXmlGDocument* _tmp5_;
		GXmlGDocument* _tmp6_;
#line 64 "GDocumentTest.vala"
		_tmp2_ = fin;
#line 64 "GDocumentTest.vala"
		_tmp3_ = g_file_read (_tmp2_, NULL, &_inner_error0_);
#line 64 "GDocumentTest.vala"
		instream = _tmp3_;
#line 64 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 555 "GDocumentTest.c"
			goto __catch23_g_error;
		}
#line 65 "GDocumentTest.vala"
		_tmp4_ = instream;
#line 65 "GDocumentTest.vala"
		_tmp5_ = gxml_gdocument_new_from_stream ((GInputStream*) _tmp4_, &_inner_error0_);
#line 65 "GDocumentTest.vala"
		doc = _tmp5_;
#line 65 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 65 "GDocumentTest.vala"
			_g_object_unref0 (instream);
#line 568 "GDocumentTest.c"
			goto __catch23_g_error;
		}
#line 66 "GDocumentTest.vala"
		_tmp6_ = doc;
#line 66 "GDocumentTest.vala"
		_vala_assert (_tmp6_ != NULL, "doc != null");
#line 63 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 63 "GDocumentTest.vala"
		_g_object_unref0 (instream);
#line 579 "GDocumentTest.c"
	}
	goto __finally23;
	__catch23_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp7_;
#line 63 "GDocumentTest.vala"
		e = _inner_error0_;
#line 63 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 69 "GDocumentTest.vala"
		_tmp7_ = e->message;
#line 69 "GDocumentTest.vala"
		g_message ("GDocumentTest.vala:69: %s", _tmp7_);
#line 70 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 63 "GDocumentTest.vala"
		_g_error_free0 (e);
#line 598 "GDocumentTest.c"
	}
	__finally23:
#line 63 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 63 "GDocumentTest.vala"
		_g_object_unref0 (fin);
#line 63 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 63 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 63 "GDocumentTest.vala"
		return;
#line 611 "GDocumentTest.c"
	}
#line 60 "GDocumentTest.vala"
	_g_object_unref0 (fin);
#line 615 "GDocumentTest.c"
}

static void
___lambda7__gtest_func (void)
{
#line 60 "GDocumentTest.vala"
	__lambda7_ ();
#line 623 "GDocumentTest.c"
}

static void
__lambda8_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GString* s = NULL;
		GString* _tmp3_;
		GString* _tmp4_;
		GXmlGDocument* d = NULL;
		GString* _tmp5_;
		const gchar* _tmp6_;
		GXmlGDocument* _tmp7_;
		GFile* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		GXmlGDocument* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		GXmlGDocument* _tmp18_;
		GFile* _tmp19_;
		GFile* _tmp20_;
		GXmlGDocument* d2 = NULL;
		GFile* _tmp21_;
		GXmlGDocument* _tmp22_;
		GXmlGDocument* _tmp23_;
		GXmlGDocument* _tmp24_;
		GXmlNode* _tmp25_;
		GXmlNode* _tmp26_;
		GXmlNode* _tmp27_;
		GXmlGDocument* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GFile* _tmp35_;
#line 75 "GDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/tw-test-file.xml");
#line 75 "GDocumentTest.vala"
		f = _tmp0_;
#line 76 "GDocumentTest.vala"
		_tmp1_ = f;
#line 76 "GDocumentTest.vala"
		if (g_file_query_exists (_tmp1_, NULL)) {
#line 678 "GDocumentTest.c"
			GFile* _tmp2_;
#line 76 "GDocumentTest.vala"
			_tmp2_ = f;
#line 76 "GDocumentTest.vala"
			g_file_delete (_tmp2_, NULL, &_inner_error0_);
#line 76 "GDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 76 "GDocumentTest.vala"
				_g_object_unref0 (f);
#line 688 "GDocumentTest.c"
				goto __catch24_g_error;
			}
		}
#line 77 "GDocumentTest.vala"
		_tmp3_ = g_string_new ("");
#line 77 "GDocumentTest.vala"
		s = _tmp3_;
#line 78 "GDocumentTest.vala"
		_tmp4_ = s;
#line 78 "GDocumentTest.vala"
		g_string_append (_tmp4_, "<root />");
#line 79 "GDocumentTest.vala"
		_tmp5_ = s;
#line 79 "GDocumentTest.vala"
		_tmp6_ = _tmp5_->str;
#line 79 "GDocumentTest.vala"
		_tmp7_ = gxml_gdocument_new_from_string (_tmp6_, 0, &_inner_error0_);
#line 79 "GDocumentTest.vala"
		d = _tmp7_;
#line 79 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 79 "GDocumentTest.vala"
			_g_string_free0 (s);
#line 79 "GDocumentTest.vala"
			_g_object_unref0 (f);
#line 714 "GDocumentTest.c"
			goto __catch24_g_error;
		}
#line 80 "GDocumentTest.vala"
		_tmp8_ = f;
#line 80 "GDocumentTest.vala"
		_tmp9_ = g_file_get_uri (_tmp8_);
#line 80 "GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 80 "GDocumentTest.vala"
		_tmp11_ = g_strconcat ("Saving to file: ", _tmp10_, NULL);
#line 80 "GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 80 "GDocumentTest.vala"
		_tmp13_ = d;
#line 80 "GDocumentTest.vala"
		_tmp14_ = gxml_gnode_to_string ((GXmlGNode*) _tmp13_);
#line 80 "GDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 80 "GDocumentTest.vala"
		_tmp16_ = g_strconcat (_tmp12_, _tmp15_, NULL);
#line 80 "GDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 80 "GDocumentTest.vala"
		g_test_message ("%s", _tmp17_);
#line 80 "GDocumentTest.vala"
		_g_free0 (_tmp17_);
#line 80 "GDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 80 "GDocumentTest.vala"
		_g_free0 (_tmp12_);
#line 80 "GDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 81 "GDocumentTest.vala"
		_tmp18_ = d;
#line 81 "GDocumentTest.vala"
		_tmp19_ = f;
#line 81 "GDocumentTest.vala"
		gxml_gdocument_save_as (_tmp18_, _tmp19_, NULL, &_inner_error0_);
#line 81 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 81 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 81 "GDocumentTest.vala"
			_g_string_free0 (s);
#line 81 "GDocumentTest.vala"
			_g_object_unref0 (f);
#line 761 "GDocumentTest.c"
			goto __catch24_g_error;
		}
#line 82 "GDocumentTest.vala"
		_tmp20_ = f;
#line 82 "GDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp20_, NULL), "f.query_exists ()");
#line 83 "GDocumentTest.vala"
		_tmp21_ = f;
#line 83 "GDocumentTest.vala"
		_tmp22_ = gxml_gdocument_new_from_file (_tmp21_, 0, NULL, &_inner_error0_);
#line 83 "GDocumentTest.vala"
		d2 = _tmp22_;
#line 83 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 83 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 83 "GDocumentTest.vala"
			_g_string_free0 (s);
#line 83 "GDocumentTest.vala"
			_g_object_unref0 (f);
#line 782 "GDocumentTest.c"
			goto __catch24_g_error;
		}
#line 84 "GDocumentTest.vala"
		_tmp23_ = d2;
#line 84 "GDocumentTest.vala"
		_vala_assert (_tmp23_ != NULL, "d2 != null");
#line 85 "GDocumentTest.vala"
		_tmp24_ = d2;
#line 85 "GDocumentTest.vala"
		_tmp25_ = gxml_document_get_root ((GXmlDocument*) _tmp24_);
#line 85 "GDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 85 "GDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 85 "GDocumentTest.vala"
		_vala_assert (_tmp27_ != NULL, "d2.root != null");
#line 85 "GDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 86 "GDocumentTest.vala"
		_tmp28_ = d2;
#line 86 "GDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) _tmp28_);
#line 86 "GDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 86 "GDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 86 "GDocumentTest.vala"
		_tmp32_ = gxml_node_get_name (_tmp31_);
#line 86 "GDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 86 "GDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 86 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "root") == 0, "d2.root.name == \"root\"");
#line 86 "GDocumentTest.vala"
		_g_free0 (_tmp34_);
#line 86 "GDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 87 "GDocumentTest.vala"
		_tmp35_ = f;
#line 87 "GDocumentTest.vala"
		g_file_delete (_tmp35_, NULL, &_inner_error0_);
#line 87 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 87 "GDocumentTest.vala"
			_g_object_unref0 (d2);
#line 87 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 87 "GDocumentTest.vala"
			_g_string_free0 (s);
#line 87 "GDocumentTest.vala"
			_g_object_unref0 (f);
#line 835 "GDocumentTest.c"
			goto __catch24_g_error;
		}
#line 74 "GDocumentTest.vala"
		_g_object_unref0 (d2);
#line 74 "GDocumentTest.vala"
		_g_object_unref0 (d);
#line 74 "GDocumentTest.vala"
		_g_string_free0 (s);
#line 74 "GDocumentTest.vala"
		_g_object_unref0 (f);
#line 846 "GDocumentTest.c"
	}
	goto __finally24;
	__catch24_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
#line 74 "GDocumentTest.vala"
		e = _inner_error0_;
#line 74 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 89 "GDocumentTest.vala"
		_tmp36_ = e->message;
#line 89 "GDocumentTest.vala"
		_tmp37_ = g_strconcat ("Error: ", _tmp36_, NULL);
#line 89 "GDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 89 "GDocumentTest.vala"
		g_message ("GDocumentTest.vala:89: %s", _tmp38_);
#line 89 "GDocumentTest.vala"
		_g_free0 (_tmp38_);
#line 90 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 74 "GDocumentTest.vala"
		_g_error_free0 (e);
#line 873 "GDocumentTest.c"
	}
	__finally24:
#line 74 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 74 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 74 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 74 "GDocumentTest.vala"
		return;
#line 884 "GDocumentTest.c"
	}
}

static void
___lambda8__gtest_func (void)
{
#line 73 "GDocumentTest.vala"
	__lambda8_ ();
#line 893 "GDocumentTest.c"
}

static void
__lambda9_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* rf = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlGDocument* d = NULL;
		GFile* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlGDocument* _tmp4_;
		GXmlGDocument* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlGDocument* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gboolean fname = FALSE;
		gboolean fshordesc = FALSE;
		gboolean fdescription = FALSE;
		gboolean fhomepage = FALSE;
		GFile* f = NULL;
		GFile* _tmp48_;
		GXmlGDocument* _tmp49_;
		GFile* _tmp50_;
		GFile* _tmp51_;
		GFile* _tmp52_;
#line 95 "GDocumentTest.vala"
		_tmp0_ = g_file_new_for_uri ("https://git.gnome.org/browse/gxml/plain/gxml.doap");
#line 95 "GDocumentTest.vala"
		rf = _tmp0_;
#line 96 "GDocumentTest.vala"
		_tmp1_ = rf;
#line 96 "GDocumentTest.vala"
		if (!g_file_query_exists (_tmp1_, NULL)) {
#line 97 "GDocumentTest.vala"
			g_message ("GDocumentTest.vala:97: No remote file available. Skiping...");
#line 98 "GDocumentTest.vala"
			_g_object_unref0 (rf);
#line 98 "GDocumentTest.vala"
			return;
#line 943 "GDocumentTest.c"
		}
#line 100 "GDocumentTest.vala"
		_tmp2_ = rf;
#line 100 "GDocumentTest.vala"
		_tmp3_ = gxml_gdocument_new_from_file (_tmp2_, 0, NULL, &_inner_error0_);
#line 100 "GDocumentTest.vala"
		d = _tmp3_;
#line 100 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 100 "GDocumentTest.vala"
			_g_object_unref0 (rf);
#line 955 "GDocumentTest.c"
			goto __catch25_g_error;
		}
#line 101 "GDocumentTest.vala"
		_tmp4_ = d;
#line 101 "GDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "d != null");
#line 102 "GDocumentTest.vala"
		_tmp5_ = d;
#line 102 "GDocumentTest.vala"
		_tmp6_ = gxml_document_get_root ((GXmlDocument*) _tmp5_);
#line 102 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 102 "GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 102 "GDocumentTest.vala"
		_vala_assert (_tmp8_ != NULL, "d.root != null");
#line 102 "GDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 103 "GDocumentTest.vala"
		_tmp9_ = d;
#line 103 "GDocumentTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) _tmp9_);
#line 103 "GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 103 "GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 103 "GDocumentTest.vala"
		_tmp13_ = gxml_node_get_name (_tmp12_);
#line 103 "GDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 103 "GDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 103 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "Project") == 0, "d.root.name == \"Project\"");
#line 103 "GDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 103 "GDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 105 "GDocumentTest.vala"
		fhomepage = FALSE;
#line 105 "GDocumentTest.vala"
		fdescription = fhomepage;
#line 105 "GDocumentTest.vala"
		fshordesc = fdescription;
#line 105 "GDocumentTest.vala"
		fname = fshordesc;
#line 1002 "GDocumentTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlGDocument* _tmp16_;
			GXmlNode* _tmp17_;
			GXmlNode* _tmp18_;
			GXmlNode* _tmp19_;
			GeeBidirList* _tmp20_;
			GeeBidirList* _tmp21_;
			GeeBidirList* _tmp22_;
			gint _n_size = 0;
			GeeBidirList* _tmp23_;
			gint _tmp24_;
			gint _tmp25_;
			gint _n_index = 0;
#line 106 "GDocumentTest.vala"
			_tmp16_ = d;
#line 106 "GDocumentTest.vala"
			_tmp17_ = gxml_document_get_root ((GXmlDocument*) _tmp16_);
#line 106 "GDocumentTest.vala"
			_tmp18_ = _tmp17_;
#line 106 "GDocumentTest.vala"
			_tmp19_ = _tmp18_;
#line 106 "GDocumentTest.vala"
			_tmp20_ = gxml_node_get_children_nodes (_tmp19_);
#line 106 "GDocumentTest.vala"
			_tmp21_ = _tmp20_;
#line 106 "GDocumentTest.vala"
			_tmp22_ = _tmp21_;
#line 106 "GDocumentTest.vala"
			_g_object_unref0 (_tmp19_);
#line 106 "GDocumentTest.vala"
			_n_list = _tmp22_;
#line 106 "GDocumentTest.vala"
			_tmp23_ = _n_list;
#line 106 "GDocumentTest.vala"
			_tmp24_ = gee_collection_get_size ((GeeCollection*) _tmp23_);
#line 106 "GDocumentTest.vala"
			_tmp25_ = _tmp24_;
#line 106 "GDocumentTest.vala"
			_n_size = _tmp25_;
#line 106 "GDocumentTest.vala"
			_n_index = -1;
#line 106 "GDocumentTest.vala"
			while (TRUE) {
#line 1047 "GDocumentTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp26_;
				gpointer _tmp27_;
				GXmlNode* _tmp28_;
				gchar* _tmp29_;
				gchar* _tmp30_;
				gchar* _tmp31_;
				gboolean _tmp32_;
				GXmlNode* _tmp33_;
				gchar* _tmp34_;
				gchar* _tmp35_;
				gchar* _tmp36_;
				gboolean _tmp37_;
				GXmlNode* _tmp38_;
				gchar* _tmp39_;
				gchar* _tmp40_;
				gchar* _tmp41_;
				gboolean _tmp42_;
				GXmlNode* _tmp43_;
				gchar* _tmp44_;
				gchar* _tmp45_;
				gchar* _tmp46_;
				gboolean _tmp47_;
#line 106 "GDocumentTest.vala"
				_n_index = _n_index + 1;
#line 106 "GDocumentTest.vala"
				if (!(_n_index < _n_size)) {
#line 106 "GDocumentTest.vala"
					break;
#line 1077 "GDocumentTest.c"
				}
#line 106 "GDocumentTest.vala"
				_tmp26_ = _n_list;
#line 106 "GDocumentTest.vala"
				_tmp27_ = gee_list_get ((GeeList*) _tmp26_, _n_index);
#line 106 "GDocumentTest.vala"
				n = (GXmlNode*) _tmp27_;
#line 107 "GDocumentTest.vala"
				_tmp28_ = n;
#line 107 "GDocumentTest.vala"
				_tmp29_ = gxml_node_get_name (_tmp28_);
#line 107 "GDocumentTest.vala"
				_tmp30_ = _tmp29_;
#line 107 "GDocumentTest.vala"
				_tmp31_ = _tmp30_;
#line 107 "GDocumentTest.vala"
				_tmp32_ = g_strcmp0 (_tmp31_, "name") == 0;
#line 107 "GDocumentTest.vala"
				_g_free0 (_tmp31_);
#line 107 "GDocumentTest.vala"
				if (_tmp32_) {
#line 107 "GDocumentTest.vala"
					fname = TRUE;
#line 1101 "GDocumentTest.c"
				}
#line 108 "GDocumentTest.vala"
				_tmp33_ = n;
#line 108 "GDocumentTest.vala"
				_tmp34_ = gxml_node_get_name (_tmp33_);
#line 108 "GDocumentTest.vala"
				_tmp35_ = _tmp34_;
#line 108 "GDocumentTest.vala"
				_tmp36_ = _tmp35_;
#line 108 "GDocumentTest.vala"
				_tmp37_ = g_strcmp0 (_tmp36_, "shortdesc") == 0;
#line 108 "GDocumentTest.vala"
				_g_free0 (_tmp36_);
#line 108 "GDocumentTest.vala"
				if (_tmp37_) {
#line 108 "GDocumentTest.vala"
					fshordesc = TRUE;
#line 1119 "GDocumentTest.c"
				}
#line 109 "GDocumentTest.vala"
				_tmp38_ = n;
#line 109 "GDocumentTest.vala"
				_tmp39_ = gxml_node_get_name (_tmp38_);
#line 109 "GDocumentTest.vala"
				_tmp40_ = _tmp39_;
#line 109 "GDocumentTest.vala"
				_tmp41_ = _tmp40_;
#line 109 "GDocumentTest.vala"
				_tmp42_ = g_strcmp0 (_tmp41_, "description") == 0;
#line 109 "GDocumentTest.vala"
				_g_free0 (_tmp41_);
#line 109 "GDocumentTest.vala"
				if (_tmp42_) {
#line 109 "GDocumentTest.vala"
					fdescription = TRUE;
#line 1137 "GDocumentTest.c"
				}
#line 110 "GDocumentTest.vala"
				_tmp43_ = n;
#line 110 "GDocumentTest.vala"
				_tmp44_ = gxml_node_get_name (_tmp43_);
#line 110 "GDocumentTest.vala"
				_tmp45_ = _tmp44_;
#line 110 "GDocumentTest.vala"
				_tmp46_ = _tmp45_;
#line 110 "GDocumentTest.vala"
				_tmp47_ = g_strcmp0 (_tmp46_, "homepage") == 0;
#line 110 "GDocumentTest.vala"
				_g_free0 (_tmp46_);
#line 110 "GDocumentTest.vala"
				if (_tmp47_) {
#line 110 "GDocumentTest.vala"
					fhomepage = TRUE;
#line 1155 "GDocumentTest.c"
				}
#line 106 "GDocumentTest.vala"
				_g_object_unref0 (n);
#line 1159 "GDocumentTest.c"
			}
#line 106 "GDocumentTest.vala"
			_g_object_unref0 (_n_list);
#line 1163 "GDocumentTest.c"
		}
#line 112 "GDocumentTest.vala"
		_vala_assert (fname, "fname");
#line 113 "GDocumentTest.vala"
		_vala_assert (fshordesc, "fshordesc");
#line 114 "GDocumentTest.vala"
		_vala_assert (fdescription, "fdescription");
#line 115 "GDocumentTest.vala"
		_vala_assert (fhomepage, "fhomepage");
#line 116 "GDocumentTest.vala"
		_tmp48_ = g_file_new_for_path (TEST_SAVE_DIR "/xml.doap");
#line 116 "GDocumentTest.vala"
		f = _tmp48_;
#line 117 "GDocumentTest.vala"
		_tmp49_ = d;
#line 117 "GDocumentTest.vala"
		_tmp50_ = f;
#line 117 "GDocumentTest.vala"
		gxml_gdocument_save_as (_tmp49_, _tmp50_, NULL, &_inner_error0_);
#line 117 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 117 "GDocumentTest.vala"
			_g_object_unref0 (f);
#line 117 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 117 "GDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1191 "GDocumentTest.c"
			goto __catch25_g_error;
		}
#line 118 "GDocumentTest.vala"
		_tmp51_ = f;
#line 118 "GDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp51_, NULL), "f.query_exists ()");
#line 119 "GDocumentTest.vala"
		_tmp52_ = f;
#line 119 "GDocumentTest.vala"
		g_file_delete (_tmp52_, NULL, &_inner_error0_);
#line 119 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 119 "GDocumentTest.vala"
			_g_object_unref0 (f);
#line 119 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 119 "GDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1210 "GDocumentTest.c"
			goto __catch25_g_error;
		}
#line 94 "GDocumentTest.vala"
		_g_object_unref0 (f);
#line 94 "GDocumentTest.vala"
		_g_object_unref0 (d);
#line 94 "GDocumentTest.vala"
		_g_object_unref0 (rf);
#line 1219 "GDocumentTest.c"
	}
	goto __finally25;
	__catch25_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
#line 94 "GDocumentTest.vala"
		e = _inner_error0_;
#line 94 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 121 "GDocumentTest.vala"
		_tmp53_ = e->message;
#line 121 "GDocumentTest.vala"
		_tmp54_ = g_strconcat ("Error: ", _tmp53_, NULL);
#line 121 "GDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 121 "GDocumentTest.vala"
		g_message ("GDocumentTest.vala:121: %s", _tmp55_);
#line 121 "GDocumentTest.vala"
		_g_free0 (_tmp55_);
#line 122 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 94 "GDocumentTest.vala"
		_g_error_free0 (e);
#line 1246 "GDocumentTest.c"
	}
	__finally25:
#line 94 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 94 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 94 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 94 "GDocumentTest.vala"
		return;
#line 1257 "GDocumentTest.c"
	}
}

static void
___lambda9__gtest_func (void)
{
#line 93 "GDocumentTest.vala"
	__lambda9_ ();
#line 1266 "GDocumentTest.c"
}

static void
__lambda10_ (void)
{
	GFile* fin = NULL;
	GFileIOStream* iostream = NULL;
	GXmlGDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
	{
		GFile* _tmp0_ = NULL;
		GFileIOStream* _tmp1_ = NULL;
		GFile* _tmp2_;
		GFile* _tmp3_;
		GXmlGDocument* _tmp4_ = NULL;
		GFileIOStream* _tmp5_;
		GInputStream* _tmp6_;
		GInputStream* _tmp7_;
		GXmlGDocument* _tmp8_;
		GXmlGDocument* _tmp9_;
#line 131 "GDocumentTest.vala"
		_tmp2_ = g_file_new_tmp ("gxml.XXXXXX", &_tmp1_, &_inner_error0_);
#line 131 "GDocumentTest.vala"
		_g_object_unref0 (iostream);
#line 131 "GDocumentTest.vala"
		iostream = _tmp1_;
#line 131 "GDocumentTest.vala"
		_tmp0_ = _tmp2_;
#line 131 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1297 "GDocumentTest.c"
			goto __catch26_g_error;
		}
#line 131 "GDocumentTest.vala"
		_tmp3_ = _tmp0_;
#line 131 "GDocumentTest.vala"
		_tmp0_ = NULL;
#line 131 "GDocumentTest.vala"
		_g_object_unref0 (fin);
#line 131 "GDocumentTest.vala"
		fin = _tmp3_;
#line 132 "GDocumentTest.vala"
		_tmp5_ = iostream;
#line 132 "GDocumentTest.vala"
		_tmp6_ = g_io_stream_get_input_stream ((GIOStream*) _tmp5_);
#line 132 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 132 "GDocumentTest.vala"
		_tmp8_ = gxml_gdocument_new_from_stream (_tmp7_, &_inner_error0_);
#line 132 "GDocumentTest.vala"
		_tmp4_ = _tmp8_;
#line 132 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 132 "GDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1322 "GDocumentTest.c"
			goto __catch26_g_error;
		}
#line 132 "GDocumentTest.vala"
		_tmp9_ = _tmp4_;
#line 132 "GDocumentTest.vala"
		_tmp4_ = NULL;
#line 132 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 132 "GDocumentTest.vala"
		doc = _tmp9_;
#line 133 "GDocumentTest.vala"
		g_message ("GDocumentTest.vala:133: Passed parse error stream");
#line 134 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 130 "GDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 130 "GDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1341 "GDocumentTest.c"
	}
	goto __finally26;
	__catch26_g_error:
	{
#line 130 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 130 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 1350 "GDocumentTest.c"
	}
	__finally26:
#line 130 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 130 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 130 "GDocumentTest.vala"
		_g_object_unref0 (iostream);
#line 130 "GDocumentTest.vala"
		_g_object_unref0 (fin);
#line 130 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 130 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 130 "GDocumentTest.vala"
		return;
#line 1367 "GDocumentTest.c"
	}
#line 125 "GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 125 "GDocumentTest.vala"
	_g_object_unref0 (iostream);
#line 125 "GDocumentTest.vala"
	_g_object_unref0 (fin);
#line 1375 "GDocumentTest.c"
}

static void
___lambda10__gtest_func (void)
{
#line 125 "GDocumentTest.vala"
	__lambda10_ ();
#line 1383 "GDocumentTest.c"
}

static void
__lambda11_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* xml = NULL;
		GXmlGDocument* doc = NULL;
		GXmlNode* root = NULL;
		gchar* _tmp0_;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GeeBidirList* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GXmlNode* n1 = NULL;
		GeeBidirList* _tmp17_;
		GeeBidirList* _tmp18_;
		GeeBidirList* _tmp19_;
		gpointer _tmp20_;
		GXmlNode* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
#line 143 "GDocumentTest.vala"
		_tmp0_ = g_strdup ("<Fruits><Apple></Apple><Orange></Orange></Fruits>");
#line 143 "GDocumentTest.vala"
		_g_free0 (xml);
#line 143 "GDocumentTest.vala"
		xml = _tmp0_;
#line 144 "GDocumentTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string (xml, 0, &_inner_error0_);
#line 144 "GDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 144 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 144 "GDocumentTest.vala"
			_g_object_unref0 (root);
#line 144 "GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 144 "GDocumentTest.vala"
			_g_free0 (xml);
#line 1438 "GDocumentTest.c"
			goto __catch27_g_error;
		}
#line 144 "GDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 144 "GDocumentTest.vala"
		_tmp1_ = NULL;
#line 144 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 144 "GDocumentTest.vala"
		doc = _tmp3_;
#line 145 "GDocumentTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 145 "GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 145 "GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 145 "GDocumentTest.vala"
		_vala_assert (_tmp6_ != NULL, "doc.root != null");
#line 145 "GDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 146 "GDocumentTest.vala"
		_tmp7_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 146 "GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 146 "GDocumentTest.vala"
		_g_object_unref0 (root);
#line 146 "GDocumentTest.vala"
		root = _tmp8_;
#line 147 "GDocumentTest.vala"
		_tmp9_ = gxml_node_get_name (root);
#line 147 "GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 147 "GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 147 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "Fruits") == 0, "root.name == \"Fruits\"");
#line 147 "GDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 148 "GDocumentTest.vala"
		_tmp12_ = gxml_node_get_children_nodes (root);
#line 148 "GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 148 "GDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 148 "GDocumentTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 148 "GDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 148 "GDocumentTest.vala"
		_vala_assert (_tmp16_ == 2, "root.children_nodes.size == 2");
#line 148 "GDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 149 "GDocumentTest.vala"
		_tmp17_ = gxml_node_get_children_nodes (root);
#line 149 "GDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 149 "GDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 149 "GDocumentTest.vala"
		_tmp20_ = gee_list_get ((GeeList*) _tmp19_, 0);
#line 149 "GDocumentTest.vala"
		_tmp21_ = (GXmlNode*) _tmp20_;
#line 149 "GDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 149 "GDocumentTest.vala"
		n1 = _tmp21_;
#line 150 "GDocumentTest.vala"
		_vala_assert (n1 != NULL, "n1 != null");
#line 151 "GDocumentTest.vala"
		_tmp22_ = gxml_node_get_name (n1);
#line 151 "GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 151 "GDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 151 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "Apple") == 0, "n1.name == \"Apple\"");
#line 151 "GDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 138 "GDocumentTest.vala"
		_g_object_unref0 (n1);
#line 138 "GDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 138 "GDocumentTest.vala"
		_g_object_unref0 (root);
#line 138 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 138 "GDocumentTest.vala"
		_g_free0 (xml);
#line 1527 "GDocumentTest.c"
	}
	goto __finally27;
	__catch27_g_error:
	{
#line 138 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 138 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 152 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 1538 "GDocumentTest.c"
	}
	__finally27:
#line 138 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 138 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 138 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 138 "GDocumentTest.vala"
		return;
#line 1549 "GDocumentTest.c"
	}
}

static void
___lambda11__gtest_func (void)
{
#line 137 "GDocumentTest.vala"
	__lambda11_ ();
#line 1558 "GDocumentTest.c"
}

static void
__lambda12_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* xml = NULL;
		GXmlGDocument* doc = NULL;
		gchar* _tmp0_;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_;
		GXmlGDocument* _tmp3_;
#line 159 "GDocumentTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>");
#line 159 "GDocumentTest.vala"
		_g_free0 (xml);
#line 159 "GDocumentTest.vala"
		xml = _tmp0_;
#line 160 "GDocumentTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string (xml, 0, &_inner_error0_);
#line 160 "GDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 160 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 160 "GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 160 "GDocumentTest.vala"
			_g_free0 (xml);
#line 1588 "GDocumentTest.c"
			goto __catch28_g_error;
		}
#line 160 "GDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 160 "GDocumentTest.vala"
		_tmp1_ = NULL;
#line 160 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 160 "GDocumentTest.vala"
		doc = _tmp3_;
#line 161 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 155 "GDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 155 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 155 "GDocumentTest.vala"
		_g_free0 (xml);
#line 1607 "GDocumentTest.c"
	}
	goto __finally28;
	__catch28_g_error:
	{
#line 155 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 155 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 1616 "GDocumentTest.c"
	}
	__finally28:
#line 155 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 155 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 155 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 155 "GDocumentTest.vala"
		return;
#line 1627 "GDocumentTest.c"
	}
}

static void
___lambda12__gtest_func (void)
{
#line 154 "GDocumentTest.vala"
	__lambda12_ ();
#line 1636 "GDocumentTest.c"
}

static void
__lambda13_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* xml = NULL;
		GXmlGDocument* doc = NULL;
		gchar* _tmp0_;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_;
		GXmlGDocument* _tmp3_;
#line 169 "GDocumentTest.vala"
		_tmp0_ = g_strdup ("");
#line 169 "GDocumentTest.vala"
		_g_free0 (xml);
#line 169 "GDocumentTest.vala"
		xml = _tmp0_;
#line 170 "GDocumentTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string (xml, 0, &_inner_error0_);
#line 170 "GDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 170 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 170 "GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 170 "GDocumentTest.vala"
			_g_free0 (xml);
#line 1666 "GDocumentTest.c"
			goto __catch29_g_error;
		}
#line 170 "GDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 170 "GDocumentTest.vala"
		_tmp1_ = NULL;
#line 170 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 170 "GDocumentTest.vala"
		doc = _tmp3_;
#line 165 "GDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 165 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 165 "GDocumentTest.vala"
		_g_free0 (xml);
#line 1683 "GDocumentTest.c"
	}
	goto __finally29;
	__catch29_g_error:
	{
#line 165 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 165 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 171 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 1694 "GDocumentTest.c"
	}
	__finally29:
#line 165 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 165 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 165 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 165 "GDocumentTest.vala"
		return;
#line 1705 "GDocumentTest.c"
	}
}

static void
___lambda13__gtest_func (void)
{
#line 164 "GDocumentTest.vala"
	__lambda13_ ();
#line 1714 "GDocumentTest.c"
}

static void
__lambda14_ (void)
{
	GXmlGDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlGDocument* _tmp2_;
		GFile* f = NULL;
		GFile* _tmp3_;
		GXmlGDocument* _tmp4_;
		GFile* _tmp5_;
		GFile* _tmp6_;
		GFile* _tmp7_;
#line 177 "GDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 177 "GDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 177 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1738 "GDocumentTest.c"
			goto __catch30_g_error;
		}
#line 177 "GDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 177 "GDocumentTest.vala"
		_tmp0_ = NULL;
#line 177 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 177 "GDocumentTest.vala"
		doc = _tmp2_;
#line 178 "GDocumentTest.vala"
		_tmp3_ = g_file_new_for_path (TEST_SAVE_DIR "/test_out_path.xml");
#line 178 "GDocumentTest.vala"
		f = _tmp3_;
#line 179 "GDocumentTest.vala"
		_tmp4_ = doc;
#line 179 "GDocumentTest.vala"
		_tmp5_ = f;
#line 179 "GDocumentTest.vala"
		gxml_gdocument_save_as (_tmp4_, _tmp5_, NULL, &_inner_error0_);
#line 179 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 179 "GDocumentTest.vala"
			_g_object_unref0 (f);
#line 179 "GDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1765 "GDocumentTest.c"
			goto __catch30_g_error;
		}
#line 180 "GDocumentTest.vala"
		_tmp6_ = f;
#line 180 "GDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp6_, NULL), "f.query_exists ()");
#line 181 "GDocumentTest.vala"
		_tmp7_ = f;
#line 181 "GDocumentTest.vala"
		g_file_delete (_tmp7_, NULL, &_inner_error0_);
#line 181 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 181 "GDocumentTest.vala"
			_g_object_unref0 (f);
#line 181 "GDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1782 "GDocumentTest.c"
			goto __catch30_g_error;
		}
#line 176 "GDocumentTest.vala"
		_g_object_unref0 (f);
#line 176 "GDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1789 "GDocumentTest.c"
	}
	goto __finally30;
	__catch30_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_;
#line 176 "GDocumentTest.vala"
		e = _inner_error0_;
#line 176 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 183 "GDocumentTest.vala"
		_tmp8_ = e->message;
#line 183 "GDocumentTest.vala"
		g_test_message ("%s", _tmp8_);
#line 184 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 176 "GDocumentTest.vala"
		_g_error_free0 (e);
#line 1808 "GDocumentTest.c"
	}
	__finally30:
#line 176 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 176 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 176 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 176 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 176 "GDocumentTest.vala"
		return;
#line 1821 "GDocumentTest.c"
	}
#line 173 "GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 1825 "GDocumentTest.c"
}

static void
___lambda14__gtest_func (void)
{
#line 173 "GDocumentTest.vala"
	__lambda14_ ();
#line 1833 "GDocumentTest.c"
}

static void
__lambda15_ (void)
{
	GXmlGDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlGDocument* _tmp2_;
		GXmlGDocument* _tmp3_;
		GFile* _tmp4_;
		GFile* _tmp5_;
#line 191 "GDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 191 "GDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 191 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1854 "GDocumentTest.c"
			goto __catch31_g_error;
		}
#line 191 "GDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 191 "GDocumentTest.vala"
		_tmp0_ = NULL;
#line 191 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 191 "GDocumentTest.vala"
		doc = _tmp2_;
#line 192 "GDocumentTest.vala"
		_tmp3_ = doc;
#line 192 "GDocumentTest.vala"
		_tmp4_ = g_file_new_for_path ("/tmp/a/b/c/d/e/f/g/h/i");
#line 192 "GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 192 "GDocumentTest.vala"
		gxml_gdocument_save_as (_tmp3_, _tmp5_, NULL, &_inner_error0_);
#line 192 "GDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 192 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 192 "GDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1879 "GDocumentTest.c"
			goto __catch31_g_error;
		}
#line 193 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 190 "GDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1886 "GDocumentTest.c"
	}
	goto __finally31;
	__catch31_g_error:
	{
#line 190 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 190 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 1895 "GDocumentTest.c"
	}
	__finally31:
#line 190 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 190 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 190 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 190 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 190 "GDocumentTest.vala"
		return;
#line 1908 "GDocumentTest.c"
	}
#line 187 "GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 1912 "GDocumentTest.c"
}

static void
___lambda15__gtest_func (void)
{
#line 187 "GDocumentTest.vala"
	__lambda15_ ();
#line 1920 "GDocumentTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 202 "GDocumentTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1928 "GDocumentTest.c"
}

static void
__lambda16_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlGElement* elem = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlGElement* _tmp4_;
		GXmlGElement* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		GXmlGElement* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		GXmlNode* _tmp13_ = NULL;
		GXmlGDocument* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlGElement* _tmp16_;
#line 199 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 199 "GDocumentTest.vala"
		doc = _tmp0_;
#line 199 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1961 "GDocumentTest.c"
			goto __catch32_g_error;
		}
#line 200 "GDocumentTest.vala"
		elem = NULL;
#line 202 "GDocumentTest.vala"
		_tmp2_ = doc;
#line 202 "GDocumentTest.vala"
		_tmp3_ = gxml_document_create_element ((GXmlDocument*) _tmp2_, "Banana", &_inner_error0_);
#line 202 "GDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 202 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 202 "GDocumentTest.vala"
			_g_object_unref0 (elem);
#line 202 "GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 1978 "GDocumentTest.c"
			goto __catch32_g_error;
		}
#line 202 "GDocumentTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 202 "GDocumentTest.vala"
		_g_object_unref0 (elem);
#line 202 "GDocumentTest.vala"
		elem = _tmp4_;
#line 203 "GDocumentTest.vala"
		_tmp5_ = elem;
#line 203 "GDocumentTest.vala"
		_tmp6_ = gxml_dom_element_get_tag_name ((GXmlDomElement*) _tmp5_);
#line 203 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 203 "GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 203 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "Banana") == 0, "elem.tag_name == \"Banana\"");
#line 203 "GDocumentTest.vala"
		_g_free0 (_tmp8_);
#line 204 "GDocumentTest.vala"
		_tmp9_ = elem;
#line 204 "GDocumentTest.vala"
		_tmp10_ = gxml_dom_element_get_tag_name ((GXmlDomElement*) _tmp9_);
#line 204 "GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 204 "GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 204 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "banana") != 0, "elem.tag_name != \"banana\"");
#line 204 "GDocumentTest.vala"
		_g_free0 (_tmp12_);
#line 206 "GDocumentTest.vala"
		_tmp14_ = doc;
#line 206 "GDocumentTest.vala"
		_tmp15_ = gxml_document_create_element ((GXmlDocument*) _tmp14_, "ØÏØÏØ¯ÏØÏ  ²øœ³¤ïØ£", &_inner_error0_);
#line 206 "GDocumentTest.vala"
		_tmp13_ = _tmp15_;
#line 206 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 206 "GDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 206 "GDocumentTest.vala"
			_g_object_unref0 (elem);
#line 206 "GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 2025 "GDocumentTest.c"
			goto __catch32_g_error;
		}
#line 206 "GDocumentTest.vala"
		_tmp16_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 206 "GDocumentTest.vala"
		_g_object_unref0 (elem);
#line 206 "GDocumentTest.vala"
		elem = _tmp16_;
#line 198 "GDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 198 "GDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 198 "GDocumentTest.vala"
		_g_object_unref0 (elem);
#line 198 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2042 "GDocumentTest.c"
	}
	goto __finally32;
	__catch32_g_error:
	{
#line 198 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 198 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 207 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 2053 "GDocumentTest.c"
	}
	__finally32:
#line 198 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 198 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 198 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 198 "GDocumentTest.vala"
		return;
#line 2064 "GDocumentTest.c"
	}
}

static void
___lambda16__gtest_func (void)
{
#line 197 "GDocumentTest.vala"
	__lambda16_ ();
#line 2073 "GDocumentTest.c"
}

static void
__lambda17_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlText* text = NULL;
		GXmlNode* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 211 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 211 "GDocumentTest.vala"
		doc = _tmp0_;
#line 211 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2097 "GDocumentTest.c"
			goto __catch33_g_error;
		}
#line 212 "GDocumentTest.vala"
		_tmp1_ = gxml_document_create_text ((GXmlDocument*) doc, "Star of my dreams");
#line 212 "GDocumentTest.vala"
		text = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_TEXT, GXmlText);
#line 214 "GDocumentTest.vala"
		_tmp2_ = gxml_node_get_name ((GXmlNode*) text);
#line 214 "GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 214 "GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 214 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "#text") == 0, "text.name == \"#text\"");
#line 214 "GDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 215 "GDocumentTest.vala"
		_tmp5_ = gxml_node_get_value ((GXmlNode*) text);
#line 215 "GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 215 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 215 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Star of my dreams") == 0, "text.value == \"Star of my dreams\"");
#line 215 "GDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 210 "GDocumentTest.vala"
		_g_object_unref0 (text);
#line 210 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2128 "GDocumentTest.c"
	}
	goto __finally33;
	__catch33_g_error:
	{
#line 210 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 210 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 216 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 2139 "GDocumentTest.c"
	}
	__finally33:
#line 210 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 210 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 210 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 210 "GDocumentTest.vala"
		return;
#line 2150 "GDocumentTest.c"
	}
}

static void
___lambda17__gtest_func (void)
{
#line 209 "GDocumentTest.vala"
	__lambda17_ ();
#line 2159 "GDocumentTest.c"
}

static void
__lambda18_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlComment* comment = NULL;
		GXmlNode* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 220 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 220 "GDocumentTest.vala"
		doc = _tmp0_;
#line 220 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2183 "GDocumentTest.c"
			goto __catch34_g_error;
		}
#line 221 "GDocumentTest.vala"
		_tmp1_ = gxml_document_create_comment ((GXmlDocument*) doc, "Ever since the day we promised.");
#line 221 "GDocumentTest.vala"
		comment = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_COMMENT, GXmlComment);
#line 223 "GDocumentTest.vala"
		_tmp2_ = gxml_node_get_name ((GXmlNode*) comment);
#line 223 "GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 223 "GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 223 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "#comment") == 0, "comment.name == \"#comment\"");
#line 223 "GDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 224 "GDocumentTest.vala"
		_tmp5_ = gxml_comment_get_str (comment);
#line 224 "GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 224 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 224 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Ever since the day we promised.") == 0, "comment.str == \"Ever since the day we promised.\"");
#line 224 "GDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 219 "GDocumentTest.vala"
		_g_object_unref0 (comment);
#line 219 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2214 "GDocumentTest.c"
	}
	goto __finally34;
	__catch34_g_error:
	{
#line 219 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 219 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 225 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 2225 "GDocumentTest.c"
	}
	__finally34:
#line 219 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 219 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 219 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 219 "GDocumentTest.vala"
		return;
#line 2236 "GDocumentTest.c"
	}
}

static void
___lambda18__gtest_func (void)
{
#line 218 "GDocumentTest.vala"
	__lambda18_ ();
#line 2245 "GDocumentTest.c"
}

static void
__lambda19_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlCDATA* cdata = NULL;
		GXmlNode* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 229 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 229 "GDocumentTest.vala"
		doc = _tmp0_;
#line 229 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2269 "GDocumentTest.c"
			goto __catch35_g_error;
		}
#line 230 "GDocumentTest.vala"
		_tmp1_ = gxml_document_create_cdata ((GXmlDocument*) doc, "put in real cdata");
#line 230 "GDocumentTest.vala"
		cdata = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_CDATA, GXmlCDATA);
#line 232 "GDocumentTest.vala"
		_tmp2_ = gxml_node_get_name ((GXmlNode*) cdata);
#line 232 "GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 232 "GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 232 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "#cdata-section") == 0, "cdata.name == \"#cdata-section\"");
#line 232 "GDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 233 "GDocumentTest.vala"
		_tmp5_ = gxml_node_get_value ((GXmlNode*) cdata);
#line 233 "GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 233 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 233 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "put in real cdata") == 0, "cdata.value == \"put in real cdata\"");
#line 233 "GDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 228 "GDocumentTest.vala"
		_g_object_unref0 (cdata);
#line 228 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2300 "GDocumentTest.c"
	}
	goto __finally35;
	__catch35_g_error:
	{
#line 228 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 228 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 234 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 2311 "GDocumentTest.c"
	}
	__finally35:
#line 228 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 228 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 228 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 228 "GDocumentTest.vala"
		return;
#line 2322 "GDocumentTest.c"
	}
}

static void
___lambda19__gtest_func (void)
{
#line 227 "GDocumentTest.vala"
	__lambda19_ ();
#line 2331 "GDocumentTest.c"
}

static void
__lambda20_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlProcessingInstruction* instruction = NULL;
		GXmlNode* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
#line 238 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 238 "GDocumentTest.vala"
		doc = _tmp0_;
#line 238 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2361 "GDocumentTest.c"
			goto __catch36_g_error;
		}
#line 239 "GDocumentTest.vala"
		_tmp1_ = gxml_document_create_pi ((GXmlDocument*) doc, "target", "data");
#line 239 "GDocumentTest.vala"
		instruction = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_PROCESSING_INSTRUCTION, GXmlProcessingInstruction);
#line 241 "GDocumentTest.vala"
		_tmp2_ = gxml_node_get_name ((GXmlNode*) instruction);
#line 241 "GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 241 "GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 241 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "target") == 0, "instruction.name == \"target\"");
#line 241 "GDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 242 "GDocumentTest.vala"
		_tmp5_ = gxml_processing_instruction_get_target (instruction);
#line 242 "GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 242 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 242 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "target") == 0, "instruction.target == \"target\"");
#line 242 "GDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 243 "GDocumentTest.vala"
		_tmp8_ = gxml_processing_instruction_get_data (instruction);
#line 243 "GDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 243 "GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 243 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "data") == 0, "instruction.data == \"data\"");
#line 243 "GDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 244 "GDocumentTest.vala"
		_tmp11_ = gxml_node_get_value ((GXmlNode*) instruction);
#line 244 "GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 244 "GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 244 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "data") == 0, "instruction.value == \"data\"");
#line 244 "GDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 237 "GDocumentTest.vala"
		_g_object_unref0 (instruction);
#line 237 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2412 "GDocumentTest.c"
	}
	goto __finally36;
	__catch36_g_error:
	{
#line 237 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 237 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 245 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 2423 "GDocumentTest.c"
	}
	__finally36:
#line 237 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 237 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 237 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 237 "GDocumentTest.vala"
		return;
#line 2434 "GDocumentTest.c"
	}
}

static void
___lambda20__gtest_func (void)
{
#line 236 "GDocumentTest.vala"
	__lambda20_ ();
#line 2443 "GDocumentTest.c"
}

static void
__lambda21_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlNode* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlGElement* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlNode* attr = NULL;
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlGElement* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
#line 249 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 249 "GDocumentTest.vala"
		doc = _tmp0_;
#line 249 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2491 "GDocumentTest.c"
			goto __catch37_g_error;
		}
#line 250 "GDocumentTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 250 "GDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 250 "GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 250 "GDocumentTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.root != null");
#line 250 "GDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 251 "GDocumentTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 251 "GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 251 "GDocumentTest.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 251 "GDocumentTest.vala"
		gxml_element_set_attr ((GXmlElement*) _tmp6_, "attrname", "attrvalue");
#line 251 "GDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 252 "GDocumentTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 252 "GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 252 "GDocumentTest.vala"
		_tmp9_ = g_strconcat ("DOC:", _tmp8_, NULL);
#line 252 "GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 252 "GDocumentTest.vala"
		g_test_message ("%s", _tmp10_);
#line 252 "GDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 252 "GDocumentTest.vala"
		_g_free0 (_tmp8_);
#line 253 "GDocumentTest.vala"
		_tmp11_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 253 "GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 253 "GDocumentTest.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 253 "GDocumentTest.vala"
		_tmp14_ = gxml_element_get_attr ((GXmlElement*) _tmp13_, "attrname");
#line 253 "GDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 253 "GDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 253 "GDocumentTest.vala"
		attr = _tmp15_;
#line 254 "GDocumentTest.vala"
		_tmp16_ = gxml_node_get_name (attr);
#line 254 "GDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 254 "GDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 254 "GDocumentTest.vala"
		_tmp19_ = g_strconcat ("Attr name: ", _tmp18_, NULL);
#line 254 "GDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 254 "GDocumentTest.vala"
		g_test_message ("%s", _tmp20_);
#line 254 "GDocumentTest.vala"
		_g_free0 (_tmp20_);
#line 254 "GDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 255 "GDocumentTest.vala"
		_tmp21_ = gxml_node_get_value (attr);
#line 255 "GDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 255 "GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 255 "GDocumentTest.vala"
		_tmp24_ = g_strconcat ("Attr value: ", _tmp23_, NULL);
#line 255 "GDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 255 "GDocumentTest.vala"
		g_test_message ("%s", _tmp25_);
#line 255 "GDocumentTest.vala"
		_g_free0 (_tmp25_);
#line 255 "GDocumentTest.vala"
		_g_free0 (_tmp23_);
#line 256 "GDocumentTest.vala"
		_vala_assert (attr != NULL, "attr != null");
#line 257 "GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (attr, GXML_TYPE_GATTRIBUTE), "attr is GAttribute");
#line 258 "GDocumentTest.vala"
		_tmp26_ = gxml_node_get_name (attr);
#line 258 "GDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 258 "GDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 258 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "attrname") == 0, "attr.name == \"attrname\"");
#line 258 "GDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 259 "GDocumentTest.vala"
		_tmp29_ = gxml_node_get_value (attr);
#line 259 "GDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 259 "GDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 259 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "attrvalue") == 0, "attr.value == \"attrvalue\"");
#line 259 "GDocumentTest.vala"
		_g_free0 (_tmp31_);
#line 248 "GDocumentTest.vala"
		_g_object_unref0 (attr);
#line 248 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2602 "GDocumentTest.c"
	}
	goto __finally37;
	__catch37_g_error:
	{
#line 248 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 248 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 262 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 2613 "GDocumentTest.c"
	}
	__finally37:
#line 248 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 248 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 248 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 248 "GDocumentTest.vala"
		return;
#line 2624 "GDocumentTest.c"
	}
}

static void
___lambda21__gtest_func (void)
{
#line 247 "GDocumentTest.vala"
	__lambda21_ ();
#line 2633 "GDocumentTest.c"
}

static void
__lambda22_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		gchar* s1 = NULL;
		gchar* _tmp1_;
		gchar** cs1 = NULL;
		gchar** _tmp2_;
		gchar** _tmp3_;
		gint cs1_length1;
		gint _cs1_size_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
#line 266 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>", 0, &_inner_error0_);
#line 266 "GDocumentTest.vala"
		doc = _tmp0_;
#line 266 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2658 "GDocumentTest.c"
			goto __catch38_g_error;
		}
#line 268 "GDocumentTest.vala"
		_tmp1_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 268 "GDocumentTest.vala"
		s1 = _tmp1_;
#line 269 "GDocumentTest.vala"
		_tmp3_ = _tmp2_ = g_strsplit (s1, "\n", 0);
#line 269 "GDocumentTest.vala"
		cs1 = _tmp3_;
#line 269 "GDocumentTest.vala"
		cs1_length1 = _vala_array_length (_tmp2_);
#line 269 "GDocumentTest.vala"
		_cs1_size_ = cs1_length1;
#line 270 "GDocumentTest.vala"
		g_test_message ("%s", s1);
#line 271 "GDocumentTest.vala"
		_tmp4_ = cs1[0];
#line 271 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "<?xml version=\"1.0\"?>") == 0, "cs1[0] == \"<?xml version=\\\"1.0\\\"?>\"");
#line 272 "GDocumentTest.vala"
		_tmp5_ = cs1[1];
#line 272 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>") == 0, "cs1[1] == \"<Sentences><Sentence lang=\\\"en\\\">I like the colour blue.</Sentence><Sentence lang=\\\"de\\\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author><Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Author><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></Authors></Sentences>\"");
#line 265 "GDocumentTest.vala"
		cs1 = (_vala_array_free (cs1, cs1_length1, (GDestroyNotify) g_free), NULL);
#line 265 "GDocumentTest.vala"
		_g_free0 (s1);
#line 265 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2689 "GDocumentTest.c"
	}
	goto __finally38;
	__catch38_g_error:
	{
#line 265 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 265 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 273 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 2700 "GDocumentTest.c"
	}
	__finally38:
#line 265 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 265 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 265 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 265 "GDocumentTest.vala"
		return;
#line 2711 "GDocumentTest.c"
	}
}

static void
___lambda22__gtest_func (void)
{
#line 264 "GDocumentTest.vala"
	__lambda22_ ();
#line 2720 "GDocumentTest.c"
}

static void
__lambda23_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		gchar* _tmp1_;
		gchar* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GeeBidirList* _tmp15_;
		GeeBidirList* _tmp16_;
		GeeBidirList* _tmp17_;
		gint _tmp18_;
		gint _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		GeeBidirList* _tmp25_;
		GeeBidirList* _tmp26_;
		GeeBidirList* _tmp27_;
		gpointer _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		GXmlNode* _tmp32_;
		GeeBidirList* _tmp33_;
		GeeBidirList* _tmp34_;
		GeeBidirList* _tmp35_;
		gpointer _tmp36_;
		GXmlNode* _tmp37_;
		GXmlNode* _tmp38_;
		GXmlNode* _tmp39_;
		GXmlNode* _tmp40_;
		GeeBidirList* _tmp41_;
		GeeBidirList* _tmp42_;
		GeeBidirList* _tmp43_;
		gpointer _tmp44_;
		GXmlNode* _tmp45_;
		GXmlNode* _tmp46_;
		GXmlNode* _tmp47_;
		GXmlNode* _tmp48_;
		GeeBidirList* _tmp49_;
		GeeBidirList* _tmp50_;
		GeeBidirList* _tmp51_;
		gpointer _tmp52_;
		GXmlNode* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		GXmlNode* _tmp57_;
		GXmlNode* _tmp58_;
		GXmlNode* _tmp59_;
		GeeBidirList* _tmp60_;
		GeeBidirList* _tmp61_;
		GeeBidirList* _tmp62_;
		gint _tmp63_;
		gint _tmp64_;
		GXmlNode* _tmp65_;
		GXmlNode* _tmp66_;
		GXmlNode* _tmp67_;
		GeeBidirList* _tmp68_;
		GeeBidirList* _tmp69_;
		GeeBidirList* _tmp70_;
		gpointer _tmp71_;
		GXmlNode* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		gchar* _tmp75_;
		GXmlNode* _tmp76_;
		GXmlNode* _tmp77_;
		GXmlNode* _tmp78_;
		GeeBidirList* _tmp79_;
		GeeBidirList* _tmp80_;
		GeeBidirList* _tmp81_;
		gpointer _tmp82_;
		GXmlNode* _tmp83_;
		GeeBidirList* _tmp84_;
		GeeBidirList* _tmp85_;
		GeeBidirList* _tmp86_;
		gint _tmp87_;
		gint _tmp88_;
		GXmlNode* _tmp89_;
		GXmlNode* _tmp90_;
		GXmlNode* _tmp91_;
		GeeBidirList* _tmp92_;
		GeeBidirList* _tmp93_;
		GeeBidirList* _tmp94_;
		gpointer _tmp95_;
		GXmlNode* _tmp96_;
		GeeBidirList* _tmp97_;
		GeeBidirList* _tmp98_;
		GeeBidirList* _tmp99_;
		gpointer _tmp100_;
		GXmlNode* _tmp101_;
		gchar* _tmp102_;
		gchar* _tmp103_;
		gchar* _tmp104_;
		GXmlNode* _tmp105_;
		GXmlNode* _tmp106_;
		GXmlNode* _tmp107_;
		GeeBidirList* _tmp108_;
		GeeBidirList* _tmp109_;
		GeeBidirList* _tmp110_;
		gpointer _tmp111_;
		GXmlNode* _tmp112_;
		GeeBidirList* _tmp113_;
		GeeBidirList* _tmp114_;
		GeeBidirList* _tmp115_;
		gpointer _tmp116_;
		GXmlNode* _tmp117_;
		GeeBidirList* _tmp118_;
		GeeBidirList* _tmp119_;
		GeeBidirList* _tmp120_;
		gint _tmp121_;
		gint _tmp122_;
		GXmlNode* _tmp123_;
		GXmlNode* _tmp124_;
		GXmlNode* _tmp125_;
		GeeBidirList* _tmp126_;
		GeeBidirList* _tmp127_;
		GeeBidirList* _tmp128_;
		gpointer _tmp129_;
		GXmlNode* _tmp130_;
		GeeBidirList* _tmp131_;
		GeeBidirList* _tmp132_;
		GeeBidirList* _tmp133_;
		gpointer _tmp134_;
		GXmlNode* _tmp135_;
		GeeBidirList* _tmp136_;
		GeeBidirList* _tmp137_;
		GeeBidirList* _tmp138_;
		gpointer _tmp139_;
		GXmlNode* _tmp140_;
		gchar* _tmp141_;
		gchar* _tmp142_;
		gchar* _tmp143_;
		GXmlNode* _tmp144_;
		GXmlNode* _tmp145_;
		GXmlNode* _tmp146_;
		GeeBidirList* _tmp147_;
		GeeBidirList* _tmp148_;
		GeeBidirList* _tmp149_;
		gpointer _tmp150_;
		GXmlNode* _tmp151_;
		GeeBidirList* _tmp152_;
		GeeBidirList* _tmp153_;
		GeeBidirList* _tmp154_;
		gpointer _tmp155_;
		GXmlNode* _tmp156_;
		GeeBidirList* _tmp157_;
		GeeBidirList* _tmp158_;
		GeeBidirList* _tmp159_;
		gpointer _tmp160_;
		GXmlNode* _tmp161_;
		GeeBidirList* _tmp162_;
		GeeBidirList* _tmp163_;
		GeeBidirList* _tmp164_;
		gint _tmp165_;
		gint _tmp166_;
		GXmlNode* _tmp167_;
		GXmlNode* _tmp168_;
		GXmlNode* _tmp169_;
		GeeBidirList* _tmp170_;
		GeeBidirList* _tmp171_;
		GeeBidirList* _tmp172_;
		gpointer _tmp173_;
		GXmlNode* _tmp174_;
		GeeBidirList* _tmp175_;
		GeeBidirList* _tmp176_;
		GeeBidirList* _tmp177_;
		gpointer _tmp178_;
		GXmlNode* _tmp179_;
		GeeBidirList* _tmp180_;
		GeeBidirList* _tmp181_;
		GeeBidirList* _tmp182_;
		gpointer _tmp183_;
		GXmlNode* _tmp184_;
		GeeBidirList* _tmp185_;
		GeeBidirList* _tmp186_;
		GeeBidirList* _tmp187_;
		gpointer _tmp188_;
		GXmlNode* _tmp189_;
		GXmlNode* _tmp190_;
		GXmlNode* _tmp191_;
		GXmlNode* _tmp192_;
		GeeBidirList* _tmp193_;
		GeeBidirList* _tmp194_;
		GeeBidirList* _tmp195_;
		gpointer _tmp196_;
		GXmlNode* _tmp197_;
		GeeBidirList* _tmp198_;
		GeeBidirList* _tmp199_;
		GeeBidirList* _tmp200_;
		gpointer _tmp201_;
		GXmlNode* _tmp202_;
		GeeBidirList* _tmp203_;
		GeeBidirList* _tmp204_;
		GeeBidirList* _tmp205_;
		gpointer _tmp206_;
		GXmlNode* _tmp207_;
		GeeBidirList* _tmp208_;
		GeeBidirList* _tmp209_;
		GeeBidirList* _tmp210_;
		gpointer _tmp211_;
		GXmlNode* _tmp212_;
		gchar* _tmp213_;
		gchar* _tmp214_;
		gchar* _tmp215_;
#line 277 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_path (TEST_DIR "/gdocument-read.xml", 0, &_inner_error0_);
#line 277 "GDocumentTest.vala"
		d = _tmp0_;
#line 277 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2951 "GDocumentTest.c"
			goto __catch39_g_error;
		}
#line 278 "GDocumentTest.vala"
		_tmp1_ = gxml_gnode_to_string ((GXmlGNode*) d);
#line 278 "GDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 278 "GDocumentTest.vala"
		g_test_message ("%s", _tmp2_);
#line 278 "GDocumentTest.vala"
		_g_free0 (_tmp2_);
#line 279 "GDocumentTest.vala"
		_tmp3_ = gxml_document_get_root ((GXmlDocument*) d);
#line 279 "GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 279 "GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 279 "GDocumentTest.vala"
		_vala_assert (_tmp5_ != NULL, "d.root != null");
#line 279 "GDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 280 "GDocumentTest.vala"
		_tmp6_ = gxml_document_get_root ((GXmlDocument*) d);
#line 280 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 280 "GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 280 "GDocumentTest.vala"
		_tmp9_ = gxml_node_get_name (_tmp8_);
#line 280 "GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 280 "GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 280 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "DataTypeTemplates") == 0, "d.root.name == \"DataTypeTemplates\"");
#line 280 "GDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 280 "GDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 281 "GDocumentTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) d);
#line 281 "GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 281 "GDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 281 "GDocumentTest.vala"
		_tmp15_ = gxml_node_get_children_nodes (_tmp14_);
#line 281 "GDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 281 "GDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 281 "GDocumentTest.vala"
		_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 281 "GDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 281 "GDocumentTest.vala"
		_tmp20_ = g_strdup_printf ("%i", _tmp19_);
#line 281 "GDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 281 "GDocumentTest.vala"
		g_test_message ("%s", _tmp21_);
#line 281 "GDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 281 "GDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 281 "GDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 282 "GDocumentTest.vala"
		_tmp22_ = gxml_document_get_root ((GXmlDocument*) d);
#line 282 "GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 282 "GDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 282 "GDocumentTest.vala"
		_tmp25_ = gxml_node_get_children_nodes (_tmp24_);
#line 282 "GDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 282 "GDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 282 "GDocumentTest.vala"
		_tmp28_ = gee_list_get ((GeeList*) _tmp27_, 0);
#line 282 "GDocumentTest.vala"
		_tmp29_ = (GXmlNode*) _tmp28_;
#line 282 "GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, GXML_TYPE_TEXT), "d.root.children_nodes[0] is GXml.Text");
#line 282 "GDocumentTest.vala"
		_g_object_unref0 (_tmp29_);
#line 282 "GDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 282 "GDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 283 "GDocumentTest.vala"
		_tmp30_ = gxml_document_get_root ((GXmlDocument*) d);
#line 283 "GDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 283 "GDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 283 "GDocumentTest.vala"
		_tmp33_ = gxml_node_get_children_nodes (_tmp32_);
#line 283 "GDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 283 "GDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 283 "GDocumentTest.vala"
		_tmp36_ = gee_list_get ((GeeList*) _tmp35_, 1);
#line 283 "GDocumentTest.vala"
		_tmp37_ = (GXmlNode*) _tmp36_;
#line 283 "GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, GXML_TYPE_ELEMENT), "d.root.children_nodes[1] is GXml.Element");
#line 283 "GDocumentTest.vala"
		_g_object_unref0 (_tmp37_);
#line 283 "GDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 283 "GDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 284 "GDocumentTest.vala"
		_tmp38_ = gxml_document_get_root ((GXmlDocument*) d);
#line 284 "GDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 284 "GDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 284 "GDocumentTest.vala"
		_tmp41_ = gxml_node_get_children_nodes (_tmp40_);
#line 284 "GDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 284 "GDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 284 "GDocumentTest.vala"
		_tmp44_ = gee_list_get ((GeeList*) _tmp43_, 2);
#line 284 "GDocumentTest.vala"
		_tmp45_ = (GXmlNode*) _tmp44_;
#line 284 "GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_TEXT), "d.root.children_nodes[2] is GXml.Text");
#line 284 "GDocumentTest.vala"
		_g_object_unref0 (_tmp45_);
#line 284 "GDocumentTest.vala"
		_g_object_unref0 (_tmp43_);
#line 284 "GDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 285 "GDocumentTest.vala"
		_tmp46_ = gxml_document_get_root ((GXmlDocument*) d);
#line 285 "GDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 285 "GDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 285 "GDocumentTest.vala"
		_tmp49_ = gxml_node_get_children_nodes (_tmp48_);
#line 285 "GDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 285 "GDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 285 "GDocumentTest.vala"
		_tmp52_ = gee_list_get ((GeeList*) _tmp51_, 2);
#line 285 "GDocumentTest.vala"
		_tmp53_ = (GXmlNode*) _tmp52_;
#line 285 "GDocumentTest.vala"
		_tmp54_ = gxml_node_get_value (_tmp53_);
#line 285 "GDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 285 "GDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 285 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "\n") == 0, "d.root.children_nodes[2].value == \"\\n\"");
#line 285 "GDocumentTest.vala"
		_g_free0 (_tmp56_);
#line 285 "GDocumentTest.vala"
		_g_object_unref0 (_tmp53_);
#line 285 "GDocumentTest.vala"
		_g_object_unref0 (_tmp51_);
#line 285 "GDocumentTest.vala"
		_g_object_unref0 (_tmp48_);
#line 286 "GDocumentTest.vala"
		_tmp57_ = gxml_document_get_root ((GXmlDocument*) d);
#line 286 "GDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 286 "GDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 286 "GDocumentTest.vala"
		_tmp60_ = gxml_node_get_children_nodes (_tmp59_);
#line 286 "GDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 286 "GDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 286 "GDocumentTest.vala"
		_tmp63_ = gee_collection_get_size ((GeeCollection*) _tmp62_);
#line 286 "GDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 286 "GDocumentTest.vala"
		_vala_assert (_tmp64_ == 3, "d.root.children_nodes.size == 3");
#line 286 "GDocumentTest.vala"
		_g_object_unref0 (_tmp62_);
#line 286 "GDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 287 "GDocumentTest.vala"
		_tmp65_ = gxml_document_get_root ((GXmlDocument*) d);
#line 287 "GDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 287 "GDocumentTest.vala"
		_tmp67_ = _tmp66_;
#line 287 "GDocumentTest.vala"
		_tmp68_ = gxml_node_get_children_nodes (_tmp67_);
#line 287 "GDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 287 "GDocumentTest.vala"
		_tmp70_ = _tmp69_;
#line 287 "GDocumentTest.vala"
		_tmp71_ = gee_list_get ((GeeList*) _tmp70_, 1);
#line 287 "GDocumentTest.vala"
		_tmp72_ = (GXmlNode*) _tmp71_;
#line 287 "GDocumentTest.vala"
		_tmp73_ = gxml_node_get_name (_tmp72_);
#line 287 "GDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 287 "GDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 287 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp75_, "DAType") == 0, "d.root.children_nodes[1].name == \"DAType\"");
#line 287 "GDocumentTest.vala"
		_g_free0 (_tmp75_);
#line 287 "GDocumentTest.vala"
		_g_object_unref0 (_tmp72_);
#line 287 "GDocumentTest.vala"
		_g_object_unref0 (_tmp70_);
#line 287 "GDocumentTest.vala"
		_g_object_unref0 (_tmp67_);
#line 288 "GDocumentTest.vala"
		_tmp76_ = gxml_document_get_root ((GXmlDocument*) d);
#line 288 "GDocumentTest.vala"
		_tmp77_ = _tmp76_;
#line 288 "GDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 288 "GDocumentTest.vala"
		_tmp79_ = gxml_node_get_children_nodes (_tmp78_);
#line 288 "GDocumentTest.vala"
		_tmp80_ = _tmp79_;
#line 288 "GDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 288 "GDocumentTest.vala"
		_tmp82_ = gee_list_get ((GeeList*) _tmp81_, 1);
#line 288 "GDocumentTest.vala"
		_tmp83_ = (GXmlNode*) _tmp82_;
#line 288 "GDocumentTest.vala"
		_tmp84_ = gxml_node_get_children_nodes (_tmp83_);
#line 288 "GDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 288 "GDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 288 "GDocumentTest.vala"
		_tmp87_ = gee_collection_get_size ((GeeCollection*) _tmp86_);
#line 288 "GDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 288 "GDocumentTest.vala"
		_vala_assert (_tmp88_ == 3, "d.root.children_nodes[1].children_nodes.size == 3");
#line 288 "GDocumentTest.vala"
		_g_object_unref0 (_tmp86_);
#line 288 "GDocumentTest.vala"
		_g_object_unref0 (_tmp83_);
#line 288 "GDocumentTest.vala"
		_g_object_unref0 (_tmp81_);
#line 288 "GDocumentTest.vala"
		_g_object_unref0 (_tmp78_);
#line 289 "GDocumentTest.vala"
		_tmp89_ = gxml_document_get_root ((GXmlDocument*) d);
#line 289 "GDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 289 "GDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 289 "GDocumentTest.vala"
		_tmp92_ = gxml_node_get_children_nodes (_tmp91_);
#line 289 "GDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 289 "GDocumentTest.vala"
		_tmp94_ = _tmp93_;
#line 289 "GDocumentTest.vala"
		_tmp95_ = gee_list_get ((GeeList*) _tmp94_, 1);
#line 289 "GDocumentTest.vala"
		_tmp96_ = (GXmlNode*) _tmp95_;
#line 289 "GDocumentTest.vala"
		_tmp97_ = gxml_node_get_children_nodes (_tmp96_);
#line 289 "GDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 289 "GDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 289 "GDocumentTest.vala"
		_tmp100_ = gee_list_get ((GeeList*) _tmp99_, 1);
#line 289 "GDocumentTest.vala"
		_tmp101_ = (GXmlNode*) _tmp100_;
#line 289 "GDocumentTest.vala"
		_tmp102_ = gxml_node_get_name (_tmp101_);
#line 289 "GDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 289 "GDocumentTest.vala"
		_tmp104_ = _tmp103_;
#line 289 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp104_, "BDA") == 0, "d.root.children_nodes[1].children_nodes[1].name == \"BDA\"");
#line 289 "GDocumentTest.vala"
		_g_free0 (_tmp104_);
#line 289 "GDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 289 "GDocumentTest.vala"
		_g_object_unref0 (_tmp99_);
#line 289 "GDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 289 "GDocumentTest.vala"
		_g_object_unref0 (_tmp94_);
#line 289 "GDocumentTest.vala"
		_g_object_unref0 (_tmp91_);
#line 290 "GDocumentTest.vala"
		_tmp105_ = gxml_document_get_root ((GXmlDocument*) d);
#line 290 "GDocumentTest.vala"
		_tmp106_ = _tmp105_;
#line 290 "GDocumentTest.vala"
		_tmp107_ = _tmp106_;
#line 290 "GDocumentTest.vala"
		_tmp108_ = gxml_node_get_children_nodes (_tmp107_);
#line 290 "GDocumentTest.vala"
		_tmp109_ = _tmp108_;
#line 290 "GDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 290 "GDocumentTest.vala"
		_tmp111_ = gee_list_get ((GeeList*) _tmp110_, 1);
#line 290 "GDocumentTest.vala"
		_tmp112_ = (GXmlNode*) _tmp111_;
#line 290 "GDocumentTest.vala"
		_tmp113_ = gxml_node_get_children_nodes (_tmp112_);
#line 290 "GDocumentTest.vala"
		_tmp114_ = _tmp113_;
#line 290 "GDocumentTest.vala"
		_tmp115_ = _tmp114_;
#line 290 "GDocumentTest.vala"
		_tmp116_ = gee_list_get ((GeeList*) _tmp115_, 1);
#line 290 "GDocumentTest.vala"
		_tmp117_ = (GXmlNode*) _tmp116_;
#line 290 "GDocumentTest.vala"
		_tmp118_ = gxml_node_get_children_nodes (_tmp117_);
#line 290 "GDocumentTest.vala"
		_tmp119_ = _tmp118_;
#line 290 "GDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 290 "GDocumentTest.vala"
		_tmp121_ = gee_collection_get_size ((GeeCollection*) _tmp120_);
#line 290 "GDocumentTest.vala"
		_tmp122_ = _tmp121_;
#line 290 "GDocumentTest.vala"
		_vala_assert (_tmp122_ == 3, "d.root.children_nodes[1].children_nodes[1].children_nodes.size == 3");
#line 290 "GDocumentTest.vala"
		_g_object_unref0 (_tmp120_);
#line 290 "GDocumentTest.vala"
		_g_object_unref0 (_tmp117_);
#line 290 "GDocumentTest.vala"
		_g_object_unref0 (_tmp115_);
#line 290 "GDocumentTest.vala"
		_g_object_unref0 (_tmp112_);
#line 290 "GDocumentTest.vala"
		_g_object_unref0 (_tmp110_);
#line 290 "GDocumentTest.vala"
		_g_object_unref0 (_tmp107_);
#line 291 "GDocumentTest.vala"
		_tmp123_ = gxml_document_get_root ((GXmlDocument*) d);
#line 291 "GDocumentTest.vala"
		_tmp124_ = _tmp123_;
#line 291 "GDocumentTest.vala"
		_tmp125_ = _tmp124_;
#line 291 "GDocumentTest.vala"
		_tmp126_ = gxml_node_get_children_nodes (_tmp125_);
#line 291 "GDocumentTest.vala"
		_tmp127_ = _tmp126_;
#line 291 "GDocumentTest.vala"
		_tmp128_ = _tmp127_;
#line 291 "GDocumentTest.vala"
		_tmp129_ = gee_list_get ((GeeList*) _tmp128_, 1);
#line 291 "GDocumentTest.vala"
		_tmp130_ = (GXmlNode*) _tmp129_;
#line 291 "GDocumentTest.vala"
		_tmp131_ = gxml_node_get_children_nodes (_tmp130_);
#line 291 "GDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 291 "GDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 291 "GDocumentTest.vala"
		_tmp134_ = gee_list_get ((GeeList*) _tmp133_, 1);
#line 291 "GDocumentTest.vala"
		_tmp135_ = (GXmlNode*) _tmp134_;
#line 291 "GDocumentTest.vala"
		_tmp136_ = gxml_node_get_children_nodes (_tmp135_);
#line 291 "GDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 291 "GDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 291 "GDocumentTest.vala"
		_tmp139_ = gee_list_get ((GeeList*) _tmp138_, 1);
#line 291 "GDocumentTest.vala"
		_tmp140_ = (GXmlNode*) _tmp139_;
#line 291 "GDocumentTest.vala"
		_tmp141_ = gxml_node_get_name (_tmp140_);
#line 291 "GDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 291 "GDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 291 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp143_, "Val") == 0, "d.root.children_nodes[1].children_nodes[1].children_nodes[1].name == \"Val\"");
#line 291 "GDocumentTest.vala"
		_g_free0 (_tmp143_);
#line 291 "GDocumentTest.vala"
		_g_object_unref0 (_tmp140_);
#line 291 "GDocumentTest.vala"
		_g_object_unref0 (_tmp138_);
#line 291 "GDocumentTest.vala"
		_g_object_unref0 (_tmp135_);
#line 291 "GDocumentTest.vala"
		_g_object_unref0 (_tmp133_);
#line 291 "GDocumentTest.vala"
		_g_object_unref0 (_tmp130_);
#line 291 "GDocumentTest.vala"
		_g_object_unref0 (_tmp128_);
#line 291 "GDocumentTest.vala"
		_g_object_unref0 (_tmp125_);
#line 292 "GDocumentTest.vala"
		_tmp144_ = gxml_document_get_root ((GXmlDocument*) d);
#line 292 "GDocumentTest.vala"
		_tmp145_ = _tmp144_;
#line 292 "GDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 292 "GDocumentTest.vala"
		_tmp147_ = gxml_node_get_children_nodes (_tmp146_);
#line 292 "GDocumentTest.vala"
		_tmp148_ = _tmp147_;
#line 292 "GDocumentTest.vala"
		_tmp149_ = _tmp148_;
#line 292 "GDocumentTest.vala"
		_tmp150_ = gee_list_get ((GeeList*) _tmp149_, 1);
#line 292 "GDocumentTest.vala"
		_tmp151_ = (GXmlNode*) _tmp150_;
#line 292 "GDocumentTest.vala"
		_tmp152_ = gxml_node_get_children_nodes (_tmp151_);
#line 292 "GDocumentTest.vala"
		_tmp153_ = _tmp152_;
#line 292 "GDocumentTest.vala"
		_tmp154_ = _tmp153_;
#line 292 "GDocumentTest.vala"
		_tmp155_ = gee_list_get ((GeeList*) _tmp154_, 1);
#line 292 "GDocumentTest.vala"
		_tmp156_ = (GXmlNode*) _tmp155_;
#line 292 "GDocumentTest.vala"
		_tmp157_ = gxml_node_get_children_nodes (_tmp156_);
#line 292 "GDocumentTest.vala"
		_tmp158_ = _tmp157_;
#line 292 "GDocumentTest.vala"
		_tmp159_ = _tmp158_;
#line 292 "GDocumentTest.vala"
		_tmp160_ = gee_list_get ((GeeList*) _tmp159_, 1);
#line 292 "GDocumentTest.vala"
		_tmp161_ = (GXmlNode*) _tmp160_;
#line 292 "GDocumentTest.vala"
		_tmp162_ = gxml_node_get_children_nodes (_tmp161_);
#line 292 "GDocumentTest.vala"
		_tmp163_ = _tmp162_;
#line 292 "GDocumentTest.vala"
		_tmp164_ = _tmp163_;
#line 292 "GDocumentTest.vala"
		_tmp165_ = gee_collection_get_size ((GeeCollection*) _tmp164_);
#line 292 "GDocumentTest.vala"
		_tmp166_ = _tmp165_;
#line 292 "GDocumentTest.vala"
		_vala_assert (_tmp166_ == 1, "d.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes.size == 1");
#line 292 "GDocumentTest.vala"
		_g_object_unref0 (_tmp164_);
#line 292 "GDocumentTest.vala"
		_g_object_unref0 (_tmp161_);
#line 292 "GDocumentTest.vala"
		_g_object_unref0 (_tmp159_);
#line 292 "GDocumentTest.vala"
		_g_object_unref0 (_tmp156_);
#line 292 "GDocumentTest.vala"
		_g_object_unref0 (_tmp154_);
#line 292 "GDocumentTest.vala"
		_g_object_unref0 (_tmp151_);
#line 292 "GDocumentTest.vala"
		_g_object_unref0 (_tmp149_);
#line 292 "GDocumentTest.vala"
		_g_object_unref0 (_tmp146_);
#line 293 "GDocumentTest.vala"
		_tmp167_ = gxml_document_get_root ((GXmlDocument*) d);
#line 293 "GDocumentTest.vala"
		_tmp168_ = _tmp167_;
#line 293 "GDocumentTest.vala"
		_tmp169_ = _tmp168_;
#line 293 "GDocumentTest.vala"
		_tmp170_ = gxml_node_get_children_nodes (_tmp169_);
#line 293 "GDocumentTest.vala"
		_tmp171_ = _tmp170_;
#line 293 "GDocumentTest.vala"
		_tmp172_ = _tmp171_;
#line 293 "GDocumentTest.vala"
		_tmp173_ = gee_list_get ((GeeList*) _tmp172_, 1);
#line 293 "GDocumentTest.vala"
		_tmp174_ = (GXmlNode*) _tmp173_;
#line 293 "GDocumentTest.vala"
		_tmp175_ = gxml_node_get_children_nodes (_tmp174_);
#line 293 "GDocumentTest.vala"
		_tmp176_ = _tmp175_;
#line 293 "GDocumentTest.vala"
		_tmp177_ = _tmp176_;
#line 293 "GDocumentTest.vala"
		_tmp178_ = gee_list_get ((GeeList*) _tmp177_, 1);
#line 293 "GDocumentTest.vala"
		_tmp179_ = (GXmlNode*) _tmp178_;
#line 293 "GDocumentTest.vala"
		_tmp180_ = gxml_node_get_children_nodes (_tmp179_);
#line 293 "GDocumentTest.vala"
		_tmp181_ = _tmp180_;
#line 293 "GDocumentTest.vala"
		_tmp182_ = _tmp181_;
#line 293 "GDocumentTest.vala"
		_tmp183_ = gee_list_get ((GeeList*) _tmp182_, 1);
#line 293 "GDocumentTest.vala"
		_tmp184_ = (GXmlNode*) _tmp183_;
#line 293 "GDocumentTest.vala"
		_tmp185_ = gxml_node_get_children_nodes (_tmp184_);
#line 293 "GDocumentTest.vala"
		_tmp186_ = _tmp185_;
#line 293 "GDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 293 "GDocumentTest.vala"
		_tmp188_ = gee_list_get ((GeeList*) _tmp187_, 0);
#line 293 "GDocumentTest.vala"
		_tmp189_ = (GXmlNode*) _tmp188_;
#line 293 "GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp189_, GXML_TYPE_TEXT), "d.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes[0] is GXml.Text");
#line 293 "GDocumentTest.vala"
		_g_object_unref0 (_tmp189_);
#line 293 "GDocumentTest.vala"
		_g_object_unref0 (_tmp187_);
#line 293 "GDocumentTest.vala"
		_g_object_unref0 (_tmp184_);
#line 293 "GDocumentTest.vala"
		_g_object_unref0 (_tmp182_);
#line 293 "GDocumentTest.vala"
		_g_object_unref0 (_tmp179_);
#line 293 "GDocumentTest.vala"
		_g_object_unref0 (_tmp177_);
#line 293 "GDocumentTest.vala"
		_g_object_unref0 (_tmp174_);
#line 293 "GDocumentTest.vala"
		_g_object_unref0 (_tmp172_);
#line 293 "GDocumentTest.vala"
		_g_object_unref0 (_tmp169_);
#line 294 "GDocumentTest.vala"
		_tmp190_ = gxml_document_get_root ((GXmlDocument*) d);
#line 294 "GDocumentTest.vala"
		_tmp191_ = _tmp190_;
#line 294 "GDocumentTest.vala"
		_tmp192_ = _tmp191_;
#line 294 "GDocumentTest.vala"
		_tmp193_ = gxml_node_get_children_nodes (_tmp192_);
#line 294 "GDocumentTest.vala"
		_tmp194_ = _tmp193_;
#line 294 "GDocumentTest.vala"
		_tmp195_ = _tmp194_;
#line 294 "GDocumentTest.vala"
		_tmp196_ = gee_list_get ((GeeList*) _tmp195_, 1);
#line 294 "GDocumentTest.vala"
		_tmp197_ = (GXmlNode*) _tmp196_;
#line 294 "GDocumentTest.vala"
		_tmp198_ = gxml_node_get_children_nodes (_tmp197_);
#line 294 "GDocumentTest.vala"
		_tmp199_ = _tmp198_;
#line 294 "GDocumentTest.vala"
		_tmp200_ = _tmp199_;
#line 294 "GDocumentTest.vala"
		_tmp201_ = gee_list_get ((GeeList*) _tmp200_, 1);
#line 294 "GDocumentTest.vala"
		_tmp202_ = (GXmlNode*) _tmp201_;
#line 294 "GDocumentTest.vala"
		_tmp203_ = gxml_node_get_children_nodes (_tmp202_);
#line 294 "GDocumentTest.vala"
		_tmp204_ = _tmp203_;
#line 294 "GDocumentTest.vala"
		_tmp205_ = _tmp204_;
#line 294 "GDocumentTest.vala"
		_tmp206_ = gee_list_get ((GeeList*) _tmp205_, 1);
#line 294 "GDocumentTest.vala"
		_tmp207_ = (GXmlNode*) _tmp206_;
#line 294 "GDocumentTest.vala"
		_tmp208_ = gxml_node_get_children_nodes (_tmp207_);
#line 294 "GDocumentTest.vala"
		_tmp209_ = _tmp208_;
#line 294 "GDocumentTest.vala"
		_tmp210_ = _tmp209_;
#line 294 "GDocumentTest.vala"
		_tmp211_ = gee_list_get ((GeeList*) _tmp210_, 0);
#line 294 "GDocumentTest.vala"
		_tmp212_ = (GXmlNode*) _tmp211_;
#line 294 "GDocumentTest.vala"
		_tmp213_ = gxml_node_get_value (_tmp212_);
#line 294 "GDocumentTest.vala"
		_tmp214_ = _tmp213_;
#line 294 "GDocumentTest.vala"
		_tmp215_ = _tmp214_;
#line 294 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp215_, "status_only") == 0, "d.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes[0].value == \"status_only\"");
#line 294 "GDocumentTest.vala"
		_g_free0 (_tmp215_);
#line 294 "GDocumentTest.vala"
		_g_object_unref0 (_tmp212_);
#line 294 "GDocumentTest.vala"
		_g_object_unref0 (_tmp210_);
#line 294 "GDocumentTest.vala"
		_g_object_unref0 (_tmp207_);
#line 294 "GDocumentTest.vala"
		_g_object_unref0 (_tmp205_);
#line 294 "GDocumentTest.vala"
		_g_object_unref0 (_tmp202_);
#line 294 "GDocumentTest.vala"
		_g_object_unref0 (_tmp200_);
#line 294 "GDocumentTest.vala"
		_g_object_unref0 (_tmp197_);
#line 294 "GDocumentTest.vala"
		_g_object_unref0 (_tmp195_);
#line 294 "GDocumentTest.vala"
		_g_object_unref0 (_tmp192_);
#line 276 "GDocumentTest.vala"
		_g_object_unref0 (d);
#line 3574 "GDocumentTest.c"
	}
	goto __finally39;
	__catch39_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp216_;
		gchar* _tmp217_;
		gchar* _tmp218_;
#line 276 "GDocumentTest.vala"
		e = _inner_error0_;
#line 276 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 295 "GDocumentTest.vala"
		_tmp216_ = e->message;
#line 295 "GDocumentTest.vala"
		_tmp217_ = g_strconcat ("ERROR: ", _tmp216_, NULL);
#line 295 "GDocumentTest.vala"
		_tmp218_ = _tmp217_;
#line 295 "GDocumentTest.vala"
		g_message ("GDocumentTest.vala:295: %s", _tmp218_);
#line 295 "GDocumentTest.vala"
		_g_free0 (_tmp218_);
#line 295 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 276 "GDocumentTest.vala"
		_g_error_free0 (e);
#line 3601 "GDocumentTest.c"
	}
	__finally39:
#line 276 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 276 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 276 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 276 "GDocumentTest.vala"
		return;
#line 3612 "GDocumentTest.c"
	}
}

static void
___lambda23__gtest_func (void)
{
#line 275 "GDocumentTest.vala"
	__lambda23_ ();
#line 3621 "GDocumentTest.c"
}

static void
__lambda24_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		gchar* s1 = NULL;
		gchar* _tmp1_;
		gchar** cs1 = NULL;
		gchar** _tmp2_;
		gchar** _tmp3_;
		gint cs1_length1;
		gint _cs1_size_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
#line 299 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>", 0, &_inner_error0_);
#line 299 "GDocumentTest.vala"
		doc = _tmp0_;
#line 299 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3646 "GDocumentTest.c"
			goto __catch40_g_error;
		}
#line 301 "GDocumentTest.vala"
		_tmp1_ = gxml_gdocument_libxml_to_string (doc);
#line 301 "GDocumentTest.vala"
		s1 = _tmp1_;
#line 302 "GDocumentTest.vala"
		_tmp3_ = _tmp2_ = g_strsplit (s1, "\n", 0);
#line 302 "GDocumentTest.vala"
		cs1 = _tmp3_;
#line 302 "GDocumentTest.vala"
		cs1_length1 = _vala_array_length (_tmp2_);
#line 302 "GDocumentTest.vala"
		_cs1_size_ = cs1_length1;
#line 303 "GDocumentTest.vala"
		g_test_message ("%s", s1);
#line 304 "GDocumentTest.vala"
		_tmp4_ = cs1[0];
#line 304 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "<?xml version=\"1.0\"?>") == 0, "cs1[0] == \"<?xml version=\\\"1.0\\\"?>\"");
#line 305 "GDocumentTest.vala"
		_tmp5_ = cs1[1];
#line 305 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>") == 0, "cs1[1] == \"<Sentences><Sentence lang=\\\"en\\\">I like the colour blue.</Sentence><Sentence lang=\\\"de\\\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author><Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Author><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></Authors></Sentences>\"");
#line 298 "GDocumentTest.vala"
		cs1 = (_vala_array_free (cs1, cs1_length1, (GDestroyNotify) g_free), NULL);
#line 298 "GDocumentTest.vala"
		_g_free0 (s1);
#line 298 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3677 "GDocumentTest.c"
	}
	goto __finally40;
	__catch40_g_error:
	{
#line 298 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 298 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 306 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 3688 "GDocumentTest.c"
	}
	__finally40:
#line 298 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 298 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 298 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 298 "GDocumentTest.vala"
		return;
#line 3699 "GDocumentTest.c"
	}
}

static void
___lambda24__gtest_func (void)
{
#line 297 "GDocumentTest.vala"
	__lambda24_ ();
#line 3708 "GDocumentTest.c"
}

static void
__lambda25_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlNode* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GeeList* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GeeList* _tmp13_;
		GeeList* _tmp14_;
		GeeList* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GeeList* _tmp21_;
		GeeList* _tmp22_;
		GeeList* _tmp23_;
		gpointer _tmp24_;
		GXmlNamespace* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		GeeList* _tmp32_;
		GeeList* _tmp33_;
		GeeList* _tmp34_;
		gpointer _tmp35_;
		GXmlNamespace* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		GXmlNode* _tmp40_;
		GXmlNode* _tmp41_;
		GXmlNode* _tmp42_;
		GeeBidirList* _tmp43_;
		GeeBidirList* _tmp44_;
		GeeBidirList* _tmp45_;
		GXmlNode* _tmp46_;
		GXmlNode* _tmp47_;
		GXmlNode* _tmp48_;
		GeeBidirList* _tmp49_;
		GeeBidirList* _tmp50_;
		GeeBidirList* _tmp51_;
		gint _tmp52_;
		gint _tmp53_;
		GXmlNode* c = NULL;
		GXmlNode* _tmp54_;
		GXmlNode* _tmp55_;
		GXmlNode* _tmp56_;
		GeeBidirList* _tmp57_;
		GeeBidirList* _tmp58_;
		GeeBidirList* _tmp59_;
		gpointer _tmp60_;
		GXmlNode* _tmp61_;
		GeeList* _tmp62_;
		GeeList* _tmp63_;
		GeeList* _tmp64_;
		GeeList* _tmp65_;
		GeeList* _tmp66_;
		GeeList* _tmp67_;
		gint _tmp68_;
		gint _tmp69_;
		GeeList* _tmp70_;
		GeeList* _tmp71_;
		GeeList* _tmp72_;
		gpointer _tmp73_;
		GXmlNamespace* _tmp74_;
		gchar* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
		GeeList* _tmp78_;
		GeeList* _tmp79_;
		GeeList* _tmp80_;
		gpointer _tmp81_;
		GXmlNamespace* _tmp82_;
		gchar* _tmp83_;
		gchar* _tmp84_;
		gchar* _tmp85_;
		GXmlNode* p = NULL;
		GXmlNode* _tmp86_;
		GXmlNode* _tmp87_;
		GXmlNode* _tmp88_;
		GXmlNode* _tmp89_;
		gchar* _tmp90_;
		gchar* _tmp91_;
		gchar* _tmp92_;
		gchar* _tmp93_;
		GXmlNode* _tmp94_;
		GXmlNode* _tmp95_;
		GXmlNode* _tmp96_;
		gchar* _tmp97_;
		gchar* _tmp98_;
		GXmlNode* _tmp99_;
		GXmlNode* _tmp100_;
		GXmlNode* _tmp101_;
		GeeList* _tmp102_;
		GeeList* _tmp103_;
		GeeList* _tmp104_;
		gpointer _tmp105_;
		GXmlNamespace* _tmp106_;
		gchar* _tmp107_;
		gchar* _tmp108_;
		gchar* _tmp109_;
		GXmlNode* _tmp110_;
		GXmlNode* _tmp111_;
		GXmlNode* _tmp112_;
		gchar* _tmp113_;
		gchar* _tmp114_;
		gchar* _tmp115_;
		gchar* _tmp116_;
		GeeMap* _tmp117_;
		GeeMap* _tmp118_;
		GeeMap* _tmp119_;
		gint _tmp120_;
		gint _tmp121_;
		GXmlNode* pt = NULL;
		GeeMap* _tmp122_;
		GeeMap* _tmp123_;
		GeeMap* _tmp124_;
		gpointer _tmp125_;
		GXmlNode* _tmp126_;
		GXmlNode* _tmp127_;
		GXmlNode* _tmp128_;
		GXmlNode* _tmp129_;
		gchar* _tmp130_;
		gchar* _tmp131_;
#line 310 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root><child/></root>", 0, &_inner_error0_);
#line 310 "GDocumentTest.vala"
		doc = _tmp0_;
#line 310 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3858 "GDocumentTest.c"
			goto __catch41_g_error;
		}
#line 311 "GDocumentTest.vala"
		gxml_gnode_set_namespace ((GXmlGNode*) doc, "http://www.gnome.org/GXml", "gxml");
#line 312 "GDocumentTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 312 "GDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 312 "GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 312 "GDocumentTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.root != null");
#line 312 "GDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 313 "GDocumentTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 313 "GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 313 "GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 313 "GDocumentTest.vala"
		_tmp7_ = gxml_node_get_namespaces (_tmp6_);
#line 313 "GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 313 "GDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 313 "GDocumentTest.vala"
		_vala_assert (_tmp9_ != NULL, "doc.root.namespaces != null");
#line 313 "GDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 313 "GDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 314 "GDocumentTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 314 "GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 314 "GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 314 "GDocumentTest.vala"
		_tmp13_ = gxml_node_get_namespaces (_tmp12_);
#line 314 "GDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 314 "GDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 314 "GDocumentTest.vala"
		_tmp16_ = gee_collection_get_size ((GeeCollection*) _tmp15_);
#line 314 "GDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 314 "GDocumentTest.vala"
		_vala_assert (_tmp17_ == 1, "doc.root.namespaces.size == 1");
#line 314 "GDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 314 "GDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 315 "GDocumentTest.vala"
		_tmp18_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 315 "GDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 315 "GDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 315 "GDocumentTest.vala"
		_tmp21_ = gxml_node_get_namespaces (_tmp20_);
#line 315 "GDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 315 "GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 315 "GDocumentTest.vala"
		_tmp24_ = gee_list_get (_tmp23_, 0);
#line 315 "GDocumentTest.vala"
		_tmp25_ = (GXmlNamespace*) _tmp24_;
#line 315 "GDocumentTest.vala"
		_tmp26_ = gxml_namespace_get_prefix (_tmp25_);
#line 315 "GDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 315 "GDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 315 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "gxml") == 0, "doc.root.namespaces[0].prefix == \"gxml\"");
#line 315 "GDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 315 "GDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 315 "GDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 315 "GDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 316 "GDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 316 "GDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 316 "GDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 316 "GDocumentTest.vala"
		_tmp32_ = gxml_node_get_namespaces (_tmp31_);
#line 316 "GDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 316 "GDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 316 "GDocumentTest.vala"
		_tmp35_ = gee_list_get (_tmp34_, 0);
#line 316 "GDocumentTest.vala"
		_tmp36_ = (GXmlNamespace*) _tmp35_;
#line 316 "GDocumentTest.vala"
		_tmp37_ = gxml_namespace_get_uri (_tmp36_);
#line 316 "GDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 316 "GDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 316 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp39_, "http://www.gnome.org/GXml") == 0, "doc.root.namespaces[0].uri == \"http://www.gnome.org/GXml\"");
#line 316 "GDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 316 "GDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 316 "GDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 316 "GDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 317 "GDocumentTest.vala"
		_tmp40_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 317 "GDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 317 "GDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 317 "GDocumentTest.vala"
		_tmp43_ = gxml_node_get_children_nodes (_tmp42_);
#line 317 "GDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 317 "GDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 317 "GDocumentTest.vala"
		_vala_assert (_tmp45_ != NULL, "doc.root.children_nodes != null");
#line 317 "GDocumentTest.vala"
		_g_object_unref0 (_tmp45_);
#line 317 "GDocumentTest.vala"
		_g_object_unref0 (_tmp42_);
#line 318 "GDocumentTest.vala"
		_tmp46_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 318 "GDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 318 "GDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 318 "GDocumentTest.vala"
		_tmp49_ = gxml_node_get_children_nodes (_tmp48_);
#line 318 "GDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 318 "GDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 318 "GDocumentTest.vala"
		_tmp52_ = gee_collection_get_size ((GeeCollection*) _tmp51_);
#line 318 "GDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 318 "GDocumentTest.vala"
		_vala_assert (_tmp53_ == 1, "doc.root.children_nodes.size == 1");
#line 318 "GDocumentTest.vala"
		_g_object_unref0 (_tmp51_);
#line 318 "GDocumentTest.vala"
		_g_object_unref0 (_tmp48_);
#line 319 "GDocumentTest.vala"
		_tmp54_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 319 "GDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 319 "GDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 319 "GDocumentTest.vala"
		_tmp57_ = gxml_node_get_children_nodes (_tmp56_);
#line 319 "GDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 319 "GDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 319 "GDocumentTest.vala"
		_tmp60_ = gee_list_get ((GeeList*) _tmp59_, 0);
#line 319 "GDocumentTest.vala"
		_tmp61_ = (GXmlNode*) _tmp60_;
#line 319 "GDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 319 "GDocumentTest.vala"
		_g_object_unref0 (_tmp56_);
#line 319 "GDocumentTest.vala"
		c = _tmp61_;
#line 320 "GDocumentTest.vala"
		gxml_node_set_namespace (c, "http://www.gnome.org/GXml2", "gxml2");
#line 321 "GDocumentTest.vala"
		_tmp62_ = gxml_node_get_namespaces (c);
#line 321 "GDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 321 "GDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 321 "GDocumentTest.vala"
		_vala_assert (_tmp64_ != NULL, "c.namespaces != null");
#line 321 "GDocumentTest.vala"
		_g_object_unref0 (_tmp64_);
#line 322 "GDocumentTest.vala"
		_tmp65_ = gxml_node_get_namespaces (c);
#line 322 "GDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 322 "GDocumentTest.vala"
		_tmp67_ = _tmp66_;
#line 322 "GDocumentTest.vala"
		_tmp68_ = gee_collection_get_size ((GeeCollection*) _tmp67_);
#line 322 "GDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 322 "GDocumentTest.vala"
		_vala_assert (_tmp69_ == 1, "c.namespaces.size == 1");
#line 322 "GDocumentTest.vala"
		_g_object_unref0 (_tmp67_);
#line 323 "GDocumentTest.vala"
		_tmp70_ = gxml_node_get_namespaces (c);
#line 323 "GDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 323 "GDocumentTest.vala"
		_tmp72_ = _tmp71_;
#line 323 "GDocumentTest.vala"
		_tmp73_ = gee_list_get (_tmp72_, 0);
#line 323 "GDocumentTest.vala"
		_tmp74_ = (GXmlNamespace*) _tmp73_;
#line 323 "GDocumentTest.vala"
		_tmp75_ = gxml_namespace_get_prefix (_tmp74_);
#line 323 "GDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 323 "GDocumentTest.vala"
		_tmp77_ = _tmp76_;
#line 323 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp77_, "gxml2") == 0, "c.namespaces[0].prefix == \"gxml2\"");
#line 323 "GDocumentTest.vala"
		_g_free0 (_tmp77_);
#line 323 "GDocumentTest.vala"
		_g_object_unref0 (_tmp74_);
#line 323 "GDocumentTest.vala"
		_g_object_unref0 (_tmp72_);
#line 324 "GDocumentTest.vala"
		_tmp78_ = gxml_node_get_namespaces (c);
#line 324 "GDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 324 "GDocumentTest.vala"
		_tmp80_ = _tmp79_;
#line 324 "GDocumentTest.vala"
		_tmp81_ = gee_list_get (_tmp80_, 0);
#line 324 "GDocumentTest.vala"
		_tmp82_ = (GXmlNamespace*) _tmp81_;
#line 324 "GDocumentTest.vala"
		_tmp83_ = gxml_namespace_get_uri (_tmp82_);
#line 324 "GDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 324 "GDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 324 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp85_, "http://www.gnome.org/GXml2") == 0, "c.namespaces[0].uri == \"http://www.gnome.org/GXml2\"");
#line 324 "GDocumentTest.vala"
		_g_free0 (_tmp85_);
#line 324 "GDocumentTest.vala"
		_g_object_unref0 (_tmp82_);
#line 324 "GDocumentTest.vala"
		_g_object_unref0 (_tmp80_);
#line 325 "GDocumentTest.vala"
		gxml_element_set_attr (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_ELEMENT) ? ((GXmlElement*) c) : NULL, "gxml:prop", "val");
#line 326 "GDocumentTest.vala"
		_tmp86_ = gxml_element_get_attr (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_ELEMENT) ? ((GXmlElement*) c) : NULL, "gxml:prop");
#line 326 "GDocumentTest.vala"
		p = _tmp86_;
#line 327 "GDocumentTest.vala"
		_vala_assert (p == NULL, "p == null");
#line 328 "GDocumentTest.vala"
		_tmp87_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 328 "GDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 328 "GDocumentTest.vala"
		_tmp89_ = _tmp88_;
#line 328 "GDocumentTest.vala"
		_tmp90_ = gxml_node_to_string (_tmp89_);
#line 328 "GDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 328 "GDocumentTest.vala"
		_tmp92_ = g_strconcat ("ROOT: ", _tmp91_, NULL);
#line 328 "GDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 328 "GDocumentTest.vala"
		g_test_message ("%s", _tmp93_);
#line 328 "GDocumentTest.vala"
		_g_free0 (_tmp93_);
#line 328 "GDocumentTest.vala"
		_g_free0 (_tmp91_);
#line 328 "GDocumentTest.vala"
		_g_object_unref0 (_tmp89_);
#line 329 "GDocumentTest.vala"
		_tmp94_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 329 "GDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 329 "GDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 329 "GDocumentTest.vala"
		_tmp97_ = gxml_node_to_string (_tmp96_);
#line 329 "GDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 329 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp98_, "<root xmlns:gxml=\"http://www.gnome.org/GXml\"><child xmlns:gxml2=\"ht" \
"tp://www.gnome.org/GXml2\"/></root>") == 0, "doc.root.to_string () == \"<root xmlns:gxml=\\\"http://www.gnome.org/GXml\\\"><child xmlns:gxml2=\\\"http://www.gnome.org/GXml2\\\"/></root>\"");
#line 329 "GDocumentTest.vala"
		_g_free0 (_tmp98_);
#line 329 "GDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 330 "GDocumentTest.vala"
		_tmp99_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 330 "GDocumentTest.vala"
		_tmp100_ = _tmp99_;
#line 330 "GDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 330 "GDocumentTest.vala"
		_tmp102_ = gxml_node_get_namespaces (_tmp101_);
#line 330 "GDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 330 "GDocumentTest.vala"
		_tmp104_ = _tmp103_;
#line 330 "GDocumentTest.vala"
		_tmp105_ = gee_list_get (_tmp104_, 0);
#line 330 "GDocumentTest.vala"
		_tmp106_ = (GXmlNamespace*) _tmp105_;
#line 330 "GDocumentTest.vala"
		_tmp107_ = gxml_namespace_get_uri (_tmp106_);
#line 330 "GDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 330 "GDocumentTest.vala"
		_tmp109_ = _tmp108_;
#line 330 "GDocumentTest.vala"
		gxml_element_set_ns_attr (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_ELEMENT) ? ((GXmlElement*) c) : NULL, _tmp109_, "prop", "Ten");
#line 330 "GDocumentTest.vala"
		_g_free0 (_tmp109_);
#line 330 "GDocumentTest.vala"
		_g_object_unref0 (_tmp106_);
#line 330 "GDocumentTest.vala"
		_g_object_unref0 (_tmp104_);
#line 330 "GDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 331 "GDocumentTest.vala"
		_tmp110_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 331 "GDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 331 "GDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 331 "GDocumentTest.vala"
		_tmp113_ = gxml_node_to_string (_tmp112_);
#line 331 "GDocumentTest.vala"
		_tmp114_ = _tmp113_;
#line 331 "GDocumentTest.vala"
		_tmp115_ = g_strconcat ("ROOT: ", _tmp114_, NULL);
#line 331 "GDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 331 "GDocumentTest.vala"
		g_test_message ("%s", _tmp116_);
#line 331 "GDocumentTest.vala"
		_g_free0 (_tmp116_);
#line 331 "GDocumentTest.vala"
		_g_free0 (_tmp114_);
#line 331 "GDocumentTest.vala"
		_g_object_unref0 (_tmp112_);
#line 332 "GDocumentTest.vala"
		_tmp117_ = gxml_node_get_attrs (c);
#line 332 "GDocumentTest.vala"
		_tmp118_ = _tmp117_;
#line 332 "GDocumentTest.vala"
		_tmp119_ = _tmp118_;
#line 332 "GDocumentTest.vala"
		_tmp120_ = gee_map_get_size (_tmp119_);
#line 332 "GDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 332 "GDocumentTest.vala"
		_vala_assert (_tmp121_ == 1, "c.attrs.size == 1");
#line 332 "GDocumentTest.vala"
		_g_object_unref0 (_tmp119_);
#line 333 "GDocumentTest.vala"
		_tmp122_ = gxml_node_get_attrs (c);
#line 333 "GDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 333 "GDocumentTest.vala"
		_tmp124_ = _tmp123_;
#line 333 "GDocumentTest.vala"
		_tmp125_ = gee_map_get (_tmp124_, "prop");
#line 333 "GDocumentTest.vala"
		_tmp126_ = (GXmlNode*) _tmp125_;
#line 333 "GDocumentTest.vala"
		_g_object_unref0 (_tmp124_);
#line 333 "GDocumentTest.vala"
		pt = _tmp126_;
#line 334 "GDocumentTest.vala"
		_vala_assert (pt != NULL, "pt != null");
#line 338 "GDocumentTest.vala"
		_tmp127_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 338 "GDocumentTest.vala"
		_tmp128_ = _tmp127_;
#line 338 "GDocumentTest.vala"
		_tmp129_ = _tmp128_;
#line 338 "GDocumentTest.vala"
		_tmp130_ = gxml_node_to_string (_tmp129_);
#line 338 "GDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 338 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp131_, "<root xmlns:gxml=\"http://www.gnome.org/GXml\"><child xmlns:gxml2=\"ht" \
"tp://www.gnome.org/GXml2\" gxml:prop=\"Ten\"/></root>") == 0, "doc.root.to_string () == \"<root xmlns:gxml=\\\"http://www.gnome.org/GXml\\\"><child xmlns:gxml2=\\\"http://www.gnome.org/GXml2\\\" gxml:prop=\\\"Ten\\\"/></root>\"");
#line 338 "GDocumentTest.vala"
		_g_free0 (_tmp131_);
#line 338 "GDocumentTest.vala"
		_g_object_unref0 (_tmp129_);
#line 309 "GDocumentTest.vala"
		_g_object_unref0 (pt);
#line 309 "GDocumentTest.vala"
		_g_object_unref0 (p);
#line 309 "GDocumentTest.vala"
		_g_object_unref0 (c);
#line 309 "GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 4267 "GDocumentTest.c"
	}
	goto __finally41;
	__catch41_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp132_;
		gchar* _tmp133_;
		gchar* _tmp134_;
#line 309 "GDocumentTest.vala"
		e = _inner_error0_;
#line 309 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 340 "GDocumentTest.vala"
		_tmp132_ = e->message;
#line 340 "GDocumentTest.vala"
		_tmp133_ = g_strconcat ("ERROR: ", _tmp132_, NULL);
#line 340 "GDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 340 "GDocumentTest.vala"
		g_message ("GDocumentTest.vala:340: %s", _tmp134_);
#line 340 "GDocumentTest.vala"
		_g_free0 (_tmp134_);
#line 341 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 309 "GDocumentTest.vala"
		_g_error_free0 (e);
#line 4294 "GDocumentTest.c"
	}
	__finally41:
#line 309 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 309 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 309 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 309 "GDocumentTest.vala"
		return;
#line 4305 "GDocumentTest.c"
	}
}

static void
___lambda25__gtest_func (void)
{
#line 308 "GDocumentTest.vala"
	__lambda25_ ();
#line 4314 "GDocumentTest.c"
}

static void
__lambda26_ (void)
{
	GXmlGDocument* doc = NULL;
	GXmlGDocument* _tmp0_;
	GXmlNode* _tmp1_;
	GXmlNode* _tmp2_;
	GXmlNode* _tmp3_;
#line 345 "GDocumentTest.vala"
	_tmp0_ = gxml_gdocument_new ();
#line 345 "GDocumentTest.vala"
	doc = _tmp0_;
#line 346 "GDocumentTest.vala"
	_tmp1_ = gxml_gnode_get_parent ((GXmlGNode*) doc);
#line 346 "GDocumentTest.vala"
	_tmp2_ = _tmp1_;
#line 346 "GDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 346 "GDocumentTest.vala"
	_vala_assert (_tmp3_ == NULL, "doc.parent == null");
#line 346 "GDocumentTest.vala"
	_g_object_unref0 (_tmp3_);
#line 344 "GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 4341 "GDocumentTest.c"
}

static void
___lambda26__gtest_func (void)
{
#line 344 "GDocumentTest.vala"
	__lambda26_ ();
#line 4349 "GDocumentTest.c"
}

static void
__lambda27_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		GXmlDomDocument* _tmp1_;
		GXmlDomElement* r = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomDocument* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomNode* _tmp6_;
		GXmlDomNode* _tmp7_;
		GXmlDomElement* c1 = NULL;
		GXmlDomDocument* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomNode* _tmp14_;
		GXmlDomElement* c2 = NULL;
		GXmlDomDocument* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c3 = NULL;
		GXmlDomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomNode* _tmp28_;
		GXmlDomElement* c4 = NULL;
		GXmlDomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomNode* _tmp35_;
		GXmlDomElement* c5 = NULL;
		GXmlDomDocument* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomNode* _tmp40_;
		GXmlDomNode* _tmp41_;
		GXmlDomElement* c51 = NULL;
		GXmlDomDocument* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomNode* _tmp46_;
		GXmlDomNode* _tmp47_;
		GXmlDomElement* n1 = NULL;
		GXmlDomDocument* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		GXmlDomElement* n2 = NULL;
		GXmlDomDocument* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		GXmlDomElement* n3 = NULL;
		GXmlDomDocument* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		GXmlDomElement* n4 = NULL;
		GXmlDomDocument* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomElement* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		GXmlDomNodeList* l1 = NULL;
		GXmlDomDocument* _tmp72_;
		GXmlDomNodeList* _tmp73_;
		GXmlDomNodeList* _tmp74_;
		GXmlDomNodeList* _tmp75_;
		gint _tmp76_;
		gint _tmp77_;
		gchar* _tmp78_;
		gchar* _tmp79_;
		GXmlDomNodeList* _tmp80_;
		gint _tmp81_;
		gint _tmp82_;
		GXmlDomNodeList* _tmp83_;
		GXmlDomNode* _tmp84_;
		GXmlDomNode* _tmp85_;
		gchar* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
		GXmlDomNodeList* l2 = NULL;
		GXmlDomDocument* _tmp89_;
		GXmlDomNodeList* _tmp90_;
		GXmlDomNodeList* _tmp91_;
		GXmlDomNodeList* _tmp92_;
		gint _tmp93_;
		gint _tmp94_;
		GXmlDomNodeList* _tmp95_;
		GXmlDomNode* _tmp96_;
		GXmlDomNode* _tmp97_;
		gchar* _tmp98_;
		gchar* _tmp99_;
		gchar* _tmp100_;
		GXmlDomNodeList* l3 = NULL;
		GXmlDomDocument* _tmp101_;
		GXmlDomNodeList* _tmp102_;
		GXmlDomNodeList* _tmp103_;
		GXmlDomNodeList* _tmp104_;
		gint _tmp105_;
		gint _tmp106_;
		GXmlDomNodeList* _tmp107_;
		GXmlDomNode* _tmp108_;
		GXmlDomNode* _tmp109_;
		gchar* _tmp110_;
		gchar* _tmp111_;
		gchar* _tmp112_;
		GXmlDomElement* c6 = NULL;
		GXmlDomDocument* _tmp113_;
		GXmlDomElement* _tmp114_;
		GXmlDomElement* _tmp115_;
		GXmlDomElement* _tmp116_;
		GXmlDomElement* _tmp117_;
		GXmlDomNode* _tmp118_;
		GXmlDomNode* _tmp119_;
		GXmlDomElement* c7 = NULL;
		GXmlDomDocument* _tmp120_;
		GXmlDomElement* _tmp121_;
		GXmlDomElement* _tmp122_;
		GXmlDomElement* _tmp123_;
		GXmlDomElement* _tmp124_;
		GXmlDomNode* _tmp125_;
		GXmlDomNode* _tmp126_;
		GXmlDomNodeList* l4 = NULL;
		GXmlDomDocument* _tmp127_;
		GXmlDomNodeList* _tmp128_;
		GXmlDomNodeList* _tmp129_;
		GXmlDomNodeList* _tmp130_;
		gint _tmp131_;
		gint _tmp132_;
		GXmlDomNodeList* _tmp133_;
		GXmlDomNode* _tmp134_;
		GXmlDomNode* _tmp135_;
		gchar* _tmp136_;
		gchar* _tmp137_;
		gchar* _tmp138_;
#line 350 "GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 350 "GDocumentTest.vala"
		_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL;
#line 350 "GDocumentTest.vala"
		if (_tmp1_ == NULL) {
#line 350 "GDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4522 "GDocumentTest.c"
		}
#line 350 "GDocumentTest.vala"
		d = _tmp1_;
#line 351 "GDocumentTest.vala"
		_tmp2_ = d;
#line 351 "GDocumentTest.vala"
		_tmp3_ = gxml_dom_document_create_element (_tmp2_, "root", &_inner_error0_);
#line 351 "GDocumentTest.vala"
		r = _tmp3_;
#line 351 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 351 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4536 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 352 "GDocumentTest.vala"
		_tmp4_ = d;
#line 352 "GDocumentTest.vala"
		_tmp5_ = r;
#line 352 "GDocumentTest.vala"
		_tmp6_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp4_, (GXmlDomNode*) _tmp5_, &_inner_error0_);
#line 352 "GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 352 "GDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 352 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 352 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 352 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4555 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 353 "GDocumentTest.vala"
		_tmp8_ = d;
#line 353 "GDocumentTest.vala"
		_tmp9_ = gxml_dom_document_create_element (_tmp8_, "child", &_inner_error0_);
#line 353 "GDocumentTest.vala"
		c1 = _tmp9_;
#line 353 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 353 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 353 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4570 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 354 "GDocumentTest.vala"
		_tmp10_ = c1;
#line 354 "GDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp10_, "class", "error", &_inner_error0_);
#line 354 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 354 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 354 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 354 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4585 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 355 "GDocumentTest.vala"
		_tmp11_ = r;
#line 355 "GDocumentTest.vala"
		_tmp12_ = c1;
#line 355 "GDocumentTest.vala"
		_tmp13_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp11_, (GXmlDomNode*) _tmp12_, &_inner_error0_);
#line 355 "GDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 355 "GDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 355 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 355 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 355 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 355 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4606 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 356 "GDocumentTest.vala"
		_tmp15_ = d;
#line 356 "GDocumentTest.vala"
		_tmp16_ = gxml_dom_document_create_element (_tmp15_, "child", &_inner_error0_);
#line 356 "GDocumentTest.vala"
		c2 = _tmp16_;
#line 356 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 356 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 356 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 356 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4623 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 357 "GDocumentTest.vala"
		_tmp17_ = c2;
#line 357 "GDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp17_, "class", "warning", &_inner_error0_);
#line 357 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 357 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 357 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 357 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 357 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4640 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 358 "GDocumentTest.vala"
		_tmp18_ = r;
#line 358 "GDocumentTest.vala"
		_tmp19_ = c2;
#line 358 "GDocumentTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error0_);
#line 358 "GDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 358 "GDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 358 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 358 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 358 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 358 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 358 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4663 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 359 "GDocumentTest.vala"
		_tmp22_ = d;
#line 359 "GDocumentTest.vala"
		_tmp23_ = gxml_dom_document_create_element (_tmp22_, "child", &_inner_error0_);
#line 359 "GDocumentTest.vala"
		c3 = _tmp23_;
#line 359 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 359 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 359 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 359 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 359 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4682 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 360 "GDocumentTest.vala"
		_tmp24_ = c3;
#line 360 "GDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp24_, "class", "error warning", &_inner_error0_);
#line 360 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 360 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 360 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 360 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 360 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 360 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4701 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 361 "GDocumentTest.vala"
		_tmp25_ = r;
#line 361 "GDocumentTest.vala"
		_tmp26_ = c3;
#line 361 "GDocumentTest.vala"
		_tmp27_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp25_, (GXmlDomNode*) _tmp26_, &_inner_error0_);
#line 361 "GDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 361 "GDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 361 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 361 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 361 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 361 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 361 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 361 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4726 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 362 "GDocumentTest.vala"
		_tmp29_ = d;
#line 362 "GDocumentTest.vala"
		_tmp30_ = gxml_dom_document_create_element (_tmp29_, "child", &_inner_error0_);
#line 362 "GDocumentTest.vala"
		c4 = _tmp30_;
#line 362 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 362 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 362 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 362 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 362 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 362 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4747 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 363 "GDocumentTest.vala"
		_tmp31_ = c4;
#line 363 "GDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp31_, "class", "error calc", &_inner_error0_);
#line 363 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 363 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 363 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 363 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 363 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 363 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 363 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4768 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 364 "GDocumentTest.vala"
		_tmp32_ = r;
#line 364 "GDocumentTest.vala"
		_tmp33_ = c4;
#line 364 "GDocumentTest.vala"
		_tmp34_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp32_, (GXmlDomNode*) _tmp33_, &_inner_error0_);
#line 364 "GDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 364 "GDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 364 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 364 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 364 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 364 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 364 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 364 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 364 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4795 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 365 "GDocumentTest.vala"
		_tmp36_ = d;
#line 365 "GDocumentTest.vala"
		_tmp37_ = gxml_dom_document_create_element (_tmp36_, "child", &_inner_error0_);
#line 365 "GDocumentTest.vala"
		c5 = _tmp37_;
#line 365 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 365 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 365 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 365 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 365 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 365 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 365 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4818 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 366 "GDocumentTest.vala"
		_tmp38_ = r;
#line 366 "GDocumentTest.vala"
		_tmp39_ = c5;
#line 366 "GDocumentTest.vala"
		_tmp40_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp38_, (GXmlDomNode*) _tmp39_, &_inner_error0_);
#line 366 "GDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 366 "GDocumentTest.vala"
		_g_object_unref0 (_tmp41_);
#line 366 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 366 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 366 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 366 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 366 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 366 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 366 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 366 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4847 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 367 "GDocumentTest.vala"
		_tmp42_ = d;
#line 367 "GDocumentTest.vala"
		_tmp43_ = gxml_dom_document_create_element (_tmp42_, "child", &_inner_error0_);
#line 367 "GDocumentTest.vala"
		c51 = _tmp43_;
#line 367 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 367 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 367 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 367 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 367 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 367 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 367 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 367 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4872 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 368 "GDocumentTest.vala"
		_tmp44_ = c5;
#line 368 "GDocumentTest.vala"
		_tmp45_ = c51;
#line 368 "GDocumentTest.vala"
		_tmp46_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp44_, (GXmlDomNode*) _tmp45_, &_inner_error0_);
#line 368 "GDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 368 "GDocumentTest.vala"
		_g_object_unref0 (_tmp47_);
#line 368 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 368 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 368 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 368 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 368 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 368 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 368 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 368 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 368 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4903 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 369 "GDocumentTest.vala"
		_tmp48_ = d;
#line 369 "GDocumentTest.vala"
		_tmp49_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp48_, "child", &_inner_error0_);
#line 369 "GDocumentTest.vala"
		n1 = _tmp49_;
#line 369 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 369 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 369 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 369 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 369 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 369 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 369 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 369 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 369 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4930 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 370 "GDocumentTest.vala"
		_tmp50_ = n1;
#line 370 "GDocumentTest.vala"
		_vala_assert (_tmp50_ != NULL, "n1 != null");
#line 371 "GDocumentTest.vala"
		_tmp51_ = n1;
#line 371 "GDocumentTest.vala"
		_tmp52_ = gxml_dom_element_get_attribute (_tmp51_, "class");
#line 371 "GDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 371 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "error") == 0, "n1.get_attribute (\"class\") == \"error\"");
#line 371 "GDocumentTest.vala"
		_g_free0 (_tmp53_);
#line 372 "GDocumentTest.vala"
		_tmp54_ = d;
#line 372 "GDocumentTest.vala"
		_tmp55_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp54_, "child.warning", &_inner_error0_);
#line 372 "GDocumentTest.vala"
		n2 = _tmp55_;
#line 372 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 372 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 372 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 372 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 372 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 372 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 372 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 372 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 372 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 372 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 4973 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 373 "GDocumentTest.vala"
		_tmp56_ = n2;
#line 373 "GDocumentTest.vala"
		_vala_assert (_tmp56_ != NULL, "n2 != null");
#line 374 "GDocumentTest.vala"
		_tmp57_ = n2;
#line 374 "GDocumentTest.vala"
		_tmp58_ = gxml_dom_element_get_attribute (_tmp57_, "class");
#line 374 "GDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 374 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "warning") == 0, "n2.get_attribute (\"class\") == \"warning\"");
#line 374 "GDocumentTest.vala"
		_g_free0 (_tmp59_);
#line 375 "GDocumentTest.vala"
		_tmp60_ = d;
#line 375 "GDocumentTest.vala"
		_tmp61_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp60_, "child[class]", &_inner_error0_);
#line 375 "GDocumentTest.vala"
		n3 = _tmp61_;
#line 375 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 375 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5018 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 376 "GDocumentTest.vala"
		_tmp62_ = n3;
#line 376 "GDocumentTest.vala"
		_vala_assert (_tmp62_ != NULL, "n3 != null");
#line 377 "GDocumentTest.vala"
		_tmp63_ = n3;
#line 377 "GDocumentTest.vala"
		_tmp64_ = gxml_dom_element_get_attribute (_tmp63_, "class");
#line 377 "GDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 377 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp65_, "error") == 0, "n3.get_attribute (\"class\") == \"error\"");
#line 377 "GDocumentTest.vala"
		_g_free0 (_tmp65_);
#line 378 "GDocumentTest.vala"
		_tmp66_ = d;
#line 378 "GDocumentTest.vala"
		_tmp67_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp66_, "child[class=\"error calc\"]", &_inner_error0_);
#line 378 "GDocumentTest.vala"
		n4 = _tmp67_;
#line 378 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 378 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5065 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 379 "GDocumentTest.vala"
		_tmp68_ = n4;
#line 379 "GDocumentTest.vala"
		_vala_assert (_tmp68_ != NULL, "n4 != null");
#line 380 "GDocumentTest.vala"
		_tmp69_ = n4;
#line 380 "GDocumentTest.vala"
		_tmp70_ = gxml_dom_element_get_attribute (_tmp69_, "class");
#line 380 "GDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 380 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp71_, "error calc") == 0, "n4.get_attribute (\"class\") == \"error calc\"");
#line 380 "GDocumentTest.vala"
		_g_free0 (_tmp71_);
#line 381 "GDocumentTest.vala"
		_tmp72_ = d;
#line 381 "GDocumentTest.vala"
		_tmp73_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp72_, "child", &_inner_error0_);
#line 381 "GDocumentTest.vala"
		l1 = _tmp73_;
#line 381 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 381 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5114 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 382 "GDocumentTest.vala"
		_tmp74_ = l1;
#line 382 "GDocumentTest.vala"
		_vala_assert (_tmp74_ != NULL, "l1 != null");
#line 383 "GDocumentTest.vala"
		_tmp75_ = l1;
#line 383 "GDocumentTest.vala"
		_tmp76_ = gxml_dom_node_list_get_length (_tmp75_);
#line 383 "GDocumentTest.vala"
		_tmp77_ = _tmp76_;
#line 383 "GDocumentTest.vala"
		_tmp78_ = g_strdup_printf ("%i", _tmp77_);
#line 383 "GDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 383 "GDocumentTest.vala"
		g_message ("GDocumentTest.vala:383: %s", _tmp79_);
#line 383 "GDocumentTest.vala"
		_g_free0 (_tmp79_);
#line 384 "GDocumentTest.vala"
		_tmp80_ = l1;
#line 384 "GDocumentTest.vala"
		_tmp81_ = gxml_dom_node_list_get_length (_tmp80_);
#line 384 "GDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 384 "GDocumentTest.vala"
		_vala_assert (_tmp82_ == 6, "l1.length == 6");
#line 385 "GDocumentTest.vala"
		_tmp83_ = l1;
#line 385 "GDocumentTest.vala"
		_tmp84_ = gxml_dom_node_list_item (_tmp83_, 4);
#line 385 "GDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 385 "GDocumentTest.vala"
		_tmp86_ = gxml_dom_node_get_node_name (_tmp85_);
#line 385 "GDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 385 "GDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 385 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp88_, "child") == 0, "l1.item (4).node_name == \"child\"");
#line 385 "GDocumentTest.vala"
		_g_free0 (_tmp88_);
#line 385 "GDocumentTest.vala"
		_g_object_unref0 (_tmp85_);
#line 386 "GDocumentTest.vala"
		_tmp89_ = d;
#line 386 "GDocumentTest.vala"
		_tmp90_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp89_, "child[class]", &_inner_error0_);
#line 386 "GDocumentTest.vala"
		l2 = _tmp90_;
#line 386 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (l1);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 386 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5195 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 387 "GDocumentTest.vala"
		_tmp91_ = l2;
#line 387 "GDocumentTest.vala"
		_vala_assert (_tmp91_ != NULL, "l2 != null");
#line 388 "GDocumentTest.vala"
		_tmp92_ = l2;
#line 388 "GDocumentTest.vala"
		_tmp93_ = gxml_dom_node_list_get_length (_tmp92_);
#line 388 "GDocumentTest.vala"
		_tmp94_ = _tmp93_;
#line 388 "GDocumentTest.vala"
		_vala_assert (_tmp94_ == 4, "l2.length == 4");
#line 389 "GDocumentTest.vala"
		_tmp95_ = l2;
#line 389 "GDocumentTest.vala"
		_tmp96_ = gxml_dom_node_list_item (_tmp95_, 3);
#line 389 "GDocumentTest.vala"
		_tmp97_ = _tmp96_;
#line 389 "GDocumentTest.vala"
		_tmp98_ = gxml_dom_node_get_node_name (_tmp97_);
#line 389 "GDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 389 "GDocumentTest.vala"
		_tmp100_ = _tmp99_;
#line 389 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp100_, "child") == 0, "l2.item (3).node_name == \"child\"");
#line 389 "GDocumentTest.vala"
		_g_free0 (_tmp100_);
#line 389 "GDocumentTest.vala"
		_g_object_unref0 (_tmp97_);
#line 390 "GDocumentTest.vala"
		_tmp101_ = d;
#line 390 "GDocumentTest.vala"
		_tmp102_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp101_, "child[class=\"error\"]", &_inner_error0_);
#line 390 "GDocumentTest.vala"
		l3 = _tmp102_;
#line 390 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (l2);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (l1);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 390 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5264 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 391 "GDocumentTest.vala"
		_tmp103_ = l3;
#line 391 "GDocumentTest.vala"
		_vala_assert (_tmp103_ != NULL, "l3 != null");
#line 392 "GDocumentTest.vala"
		_tmp104_ = l3;
#line 392 "GDocumentTest.vala"
		_tmp105_ = gxml_dom_node_list_get_length (_tmp104_);
#line 392 "GDocumentTest.vala"
		_tmp106_ = _tmp105_;
#line 392 "GDocumentTest.vala"
		_vala_assert (_tmp106_ == 1, "l3.length == 1");
#line 393 "GDocumentTest.vala"
		_tmp107_ = l3;
#line 393 "GDocumentTest.vala"
		_tmp108_ = gxml_dom_node_list_item (_tmp107_, 0);
#line 393 "GDocumentTest.vala"
		_tmp109_ = _tmp108_;
#line 393 "GDocumentTest.vala"
		_tmp110_ = gxml_dom_node_get_node_name (_tmp109_);
#line 393 "GDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 393 "GDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 393 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp112_, "child") == 0, "l3.item (0).node_name == \"child\"");
#line 393 "GDocumentTest.vala"
		_g_free0 (_tmp112_);
#line 393 "GDocumentTest.vala"
		_g_object_unref0 (_tmp109_);
#line 394 "GDocumentTest.vala"
		_tmp113_ = d;
#line 394 "GDocumentTest.vala"
		_tmp114_ = gxml_dom_document_create_element (_tmp113_, "child", &_inner_error0_);
#line 394 "GDocumentTest.vala"
		c6 = _tmp114_;
#line 394 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (l3);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (l2);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (l1);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 394 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5335 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 395 "GDocumentTest.vala"
		_tmp115_ = c6;
#line 395 "GDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp115_, "prop", "val1", &_inner_error0_);
#line 395 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (c6);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (l3);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (l2);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (l1);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 395 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5376 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 396 "GDocumentTest.vala"
		_tmp116_ = r;
#line 396 "GDocumentTest.vala"
		_tmp117_ = c6;
#line 396 "GDocumentTest.vala"
		_tmp118_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp116_, (GXmlDomNode*) _tmp117_, &_inner_error0_);
#line 396 "GDocumentTest.vala"
		_tmp119_ = _tmp118_;
#line 396 "GDocumentTest.vala"
		_g_object_unref0 (_tmp119_);
#line 396 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (c6);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (l3);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (l2);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (l1);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 396 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5423 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 397 "GDocumentTest.vala"
		_tmp120_ = d;
#line 397 "GDocumentTest.vala"
		_tmp121_ = gxml_dom_document_create_element (_tmp120_, "child", &_inner_error0_);
#line 397 "GDocumentTest.vala"
		c7 = _tmp121_;
#line 397 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (c6);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (l3);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (l2);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (l1);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 397 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5466 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 398 "GDocumentTest.vala"
		_tmp122_ = c7;
#line 398 "GDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp122_, "prop", "val1", &_inner_error0_);
#line 398 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (c7);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (c6);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (l3);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (l2);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (l1);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 398 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5509 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 399 "GDocumentTest.vala"
		_tmp123_ = r;
#line 399 "GDocumentTest.vala"
		_tmp124_ = c7;
#line 399 "GDocumentTest.vala"
		_tmp125_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp123_, (GXmlDomNode*) _tmp124_, &_inner_error0_);
#line 399 "GDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 399 "GDocumentTest.vala"
		_g_object_unref0 (_tmp126_);
#line 399 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (c7);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (c6);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (l3);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (l2);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (l1);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 399 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5558 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 400 "GDocumentTest.vala"
		_tmp127_ = d;
#line 400 "GDocumentTest.vala"
		_tmp128_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp127_, "child[prop=\"val1\"]", &_inner_error0_);
#line 400 "GDocumentTest.vala"
		l4 = _tmp128_;
#line 400 "GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (c7);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (c6);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (l3);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (l2);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (l1);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (n4);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (n3);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (n2);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (n1);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (c51);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (c5);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (c4);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (c3);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (c2);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (c1);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (r);
#line 400 "GDocumentTest.vala"
			_g_object_unref0 (d);
#line 5603 "GDocumentTest.c"
			goto __catch42_g_error;
		}
#line 401 "GDocumentTest.vala"
		_tmp129_ = l4;
#line 401 "GDocumentTest.vala"
		_vala_assert (_tmp129_ != NULL, "l4 != null");
#line 402 "GDocumentTest.vala"
		_tmp130_ = l4;
#line 402 "GDocumentTest.vala"
		_tmp131_ = gxml_dom_node_list_get_length (_tmp130_);
#line 402 "GDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 402 "GDocumentTest.vala"
		_vala_assert (_tmp132_ == 2, "l4.length == 2");
#line 403 "GDocumentTest.vala"
		_tmp133_ = l4;
#line 403 "GDocumentTest.vala"
		_tmp134_ = gxml_dom_node_list_item (_tmp133_, 0);
#line 403 "GDocumentTest.vala"
		_tmp135_ = _tmp134_;
#line 403 "GDocumentTest.vala"
		_tmp136_ = gxml_dom_node_get_node_name (_tmp135_);
#line 403 "GDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 403 "GDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 403 "GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp138_, "child") == 0, "l4.item (0).node_name == \"child\"");
#line 403 "GDocumentTest.vala"
		_g_free0 (_tmp138_);
#line 403 "GDocumentTest.vala"
		_g_object_unref0 (_tmp135_);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (l4);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (c7);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (c6);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (l3);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (l2);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (l1);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (n4);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (n3);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (n2);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (n1);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (c51);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (c5);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (c4);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (c3);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (c2);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (c1);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (r);
#line 349 "GDocumentTest.vala"
		_g_object_unref0 (d);
#line 5672 "GDocumentTest.c"
	}
	goto __finally42;
	__catch42_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp139_;
		gchar* _tmp140_;
		gchar* _tmp141_;
#line 349 "GDocumentTest.vala"
		e = _inner_error0_;
#line 349 "GDocumentTest.vala"
		_inner_error0_ = NULL;
#line 405 "GDocumentTest.vala"
		_tmp139_ = e->message;
#line 405 "GDocumentTest.vala"
		_tmp140_ = g_strconcat ("Error: ", _tmp139_, NULL);
#line 405 "GDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 405 "GDocumentTest.vala"
		g_message ("GDocumentTest.vala:405: %s", _tmp141_);
#line 405 "GDocumentTest.vala"
		_g_free0 (_tmp141_);
#line 406 "GDocumentTest.vala"
		g_assert_not_reached ();
#line 349 "GDocumentTest.vala"
		_g_error_free0 (e);
#line 5699 "GDocumentTest.c"
	}
	__finally42:
#line 349 "GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 349 "GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 349 "GDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 349 "GDocumentTest.vala"
		return;
#line 5710 "GDocumentTest.c"
	}
}

static void
___lambda27__gtest_func (void)
{
#line 348 "GDocumentTest.vala"
	__lambda27_ ();
#line 5719 "GDocumentTest.c"
}

void
gdocument_test_add_tests (void)
{
#line 29 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_api", ___lambda5__gtest_func);
#line 41 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_path_error", ___lambda6__gtest_func);
#line 60 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_stream", ___lambda7__gtest_func);
#line 73 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/gfile/local", ___lambda8__gtest_func);
#line 93 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/gfile/remote", ___lambda9__gtest_func);
#line 125 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_stream_error", ___lambda10__gtest_func);
#line 137 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_string", ___lambda11__gtest_func);
#line 154 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_string_no_root", ___lambda12__gtest_func);
#line 164 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_string_invalid", ___lambda13__gtest_func);
#line 173 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/save", ___lambda14__gtest_func);
#line 187 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/save_error", ___lambda15__gtest_func);
#line 197 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_element", ___lambda16__gtest_func);
#line 209 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_text_node", ___lambda17__gtest_func);
#line 218 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_comment", ___lambda18__gtest_func);
#line 227 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_cdata_section", ___lambda19__gtest_func);
#line 236 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_processing_instruction", ___lambda20__gtest_func);
#line 247 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_attribute", ___lambda21__gtest_func);
#line 264 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/to_string/basic", ___lambda22__gtest_func);
#line 275 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/to_string/extended", ___lambda23__gtest_func);
#line 297 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/libxml_to_string", ___lambda24__gtest_func);
#line 308 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/namespace", ___lambda25__gtest_func);
#line 344 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/parent", ___lambda26__gtest_func);
#line 348 "GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/css-selector", ___lambda27__gtest_func);
#line 5771 "GDocumentTest.c"
}

GDocumentTest*
gdocument_test_construct (GType object_type)
{
	GDocumentTest* self = NULL;
#line 27 "GDocumentTest.vala"
	self = (GDocumentTest*) gxml_test_construct (object_type);
#line 27 "GDocumentTest.vala"
	return self;
#line 5782 "GDocumentTest.c"
}

GDocumentTest*
gdocument_test_new (void)
{
#line 27 "GDocumentTest.vala"
	return gdocument_test_construct (TYPE_GDOCUMENT_TEST);
#line 5790 "GDocumentTest.c"
}

static void
gdocument_test_class_init (GDocumentTestClass * klass,
                           gpointer klass_data)
{
#line 27 "GDocumentTest.vala"
	gdocument_test_parent_class = g_type_class_peek_parent (klass);
#line 5799 "GDocumentTest.c"
}

static void
gdocument_test_instance_init (GDocumentTest * self,
                              gpointer klass)
{
}

GType
gdocument_test_get_type (void)
{
	static volatile gsize gdocument_test_type_id__volatile = 0;
	if (g_once_init_enter (&gdocument_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gdocument_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GDocumentTest), 0, (GInstanceInitFunc) gdocument_test_instance_init, NULL };
		GType gdocument_test_type_id;
		gdocument_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&gdocument_test_type_id__volatile, gdocument_test_type_id);
	}
	return gdocument_test_type_id__volatile;
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

